/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     autoexec.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Starts datamart processing
  |
  |
  | Inputs    Various environment variables
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/


%let mac_path=%sysget(VIYAHOME);
filename evmacs "&mac_path./lib/evmsvrops/SASMacros";
options insert=sasautos=(evmacs) ;


%getkeyprop(mvar=emi_cas_load, envvar=EMI_CAS_LOAD, default=Y); 
%let emi_cas_load=%upcase(&emi_cas_load);

%if %isFalse(&emi_cas_load) %then
%do; /* no loading of CAS */

   %let emi_cas_load_logs=N;
   %let emi_cas_load_metrics=N;

%end;/* no loading of CAS */
%else
%do; /* load CAS as appropriate */

   %getkeyprop(mvar=emi_cas_load_metrics, envvar=EMI_CAS_LOAD_METRICS, default=&emi_cas_load); 
   %let emi_cas_load_metrics=%upcase(&emi_cas_load_metrics);

   %getkeyprop(mvar=emi_cas_load_logs, envvar=EMI_CAS_LOAD_LOGS, default=&emi_cas_load);
   %let emi_cas_load_logs=%upcase(&emi_cas_load_logs);

%end;/* load CAS as appropriate */


%getkeyprop(mvar=SASCFGPATH);
%getkeyprop(mvar=SASPREFIX,default=/opt/sas);
%getkeyprop(mvar=SASDEPLOYID,default=viya);
%getkeyprop(mvar=SASINSTID,default=default);
%getkeyprop(mvar=VIYAHOME,default=&SASPREFIX./&SASDEPLOYID./home);


%let EVHOME=&VIYAHOME/lib/evmsvrops;
%let EVCONF=%substr(&VIYAHOME,1,%eval(%index(&VIYAHOME,%str(viya/home))-1))viya/config;
%put [&EVCONF];


%getkeyprop(mvar=runid, envvar=EMI_RUNID,default=%sysfunc(translate(%sysfunc(putn(%sysfunc(datetime()),B8601DT15)),'_','T')));


%getkeyprop(mvar=evdebug,default=1);
options noquotelenmax;

%evutils;



/* CAS connection info */
%getkeyprop(mvar=cas_server_host, envvar=EMI_SYSTEM_CAS_HOST,default=@@CAS_SERVER_HOST@@);
%getkeyprop(mvar=cas_server_host2, envvar=EMI_SYSTEM_CAS_HOST2,default=NONE);
%getkeyprop(mvar=cas_server_port, envvar=EMI_SYSTEM_CAS_PORT,default=@@CAS_SERVER_PORT@@);



/*  Name of the CASLIB in which the metric data tables are stored */
%getkeyprop(mvar=caslib_metric_data, envvar=EMI_SYSTEM_CAS_CASLIB,default=SystemData);

/*  Name of the CASLIB in which the index is stored */
%let CAS_SEARCH_CASLIB=&caslib_metric_data;

/*   Name of the CAS Search Index used to store log events  */
%let CAS_SEARCH_IDXNAME=VIYALOGS;


%jobheader(jobname=Environment Manager Autoexec);


options fullstimer ;
%let DATE=&sysdate9;

/* File containing the CAS Search Index schema defintion*/
%let schema_file = &EVHOME./schema4sas.json;

/* Static batch identifier to assign to loaded data. 
#     NOTE: Modifying this parameter is generally not needed; the special value 
#     of _DATE_ will result in a uniquie batch identifier being generated
#     as part of the load process.
#
*/
%let batch_id = _DATE_;


/* DATA MART SPECIFIC PROPERTIES */
%getkeyprop(mvar=EVDM, envvar=EMI_DATAMART_NAME, default=evdm); 
%let EVDMPATH=%str(&EVCONF./var/lib/evmsvrops/&EVDM);

/* How many days of SASLOGs to keep and when to zip TSVs */
%getkeyprop(mvar=zip_tsv_and_log_delete,envvar=EMI_ZIP_TSV_DAYS,default=1);

/* How many days of ziped TSVs to keep                   */
%getkeyprop(mvar=delete_old_zips, envvar=EMI_DELETE_TSVZIP_DAYS, default=30);

/* How many days of data to retain in CAS                */
%getkeyprop(mvar=cas_cutoff, envvar=EMI_CAS_RETAIN_DAYS, default=3);




%evsetdebug(SET);
%evdebug;


libname evdm "&evdmpath";
libname lastvals "&evdmpath/lastvals";

libname evdmfmts "&evdmpath/SASFormats";
options append=(fmtsearch=(evdmfmts));


%datamartlock(action=CHECK);
