# SAS Viya Monitoring ETL Initialization
This repository automates the enablement of SAS Viya Environment Manager monitoring ETL as it will
be deployed in 17w38. For details, please consult http://sww.sas.com/saspedia/SAS_Viya_logging_and_monitoring

## Single-instance services
These services run as singletons as part of a "server" deployment, as opposed to the "client" services that run on each deployed host.

## What is Enabled?

The following features are turned on:
* `sas-metric-sub` will listen for metric events and will assemble them into JSON array .tmp files for later SAS ETL
* `sas-log-sub` will listen for log events and will assemble them into JSON array .tmp files for Lumberyard
* `sas-watch-consul` will listen for Consul notifications and publish them to sas.notification  

optionally
* `sas-metric-etl` will convert and merge JSON array files from `sas-metric-sub` into SAS datasets at 10 minute intervals

## Prerequisites - PLEASE READ

To use these scripts, you should have:
* A `running` 17w12 SAS Viya deployment dated January 5, 2017 or later
* The deployment must include RabbitMQ and Consul (not CAS-only)
* To avoid too much manual configuration, use the default root and deployment ID (base directory of `/opt/sas/viya`)
* [git](http://git-scm.org) installed
* passwordless `sudo` access for the UserID from which you are running emi-service-init.sh

## Assumptions

This is early in the development cycle, so the following limitations hold:
* While it is possible to point this at a remote Consul and Rabbit, that is not documented pending further testing, therefore,
* This assumes a single-machine deployment with producers and consumers running on the same Viya host.

## Running

This installation assumes that you have already deployed the `viya-init/client` code running on this platform.

### Fetch the tool set, if you haven't already. The client install includes server.
Clone the repository: (standard practice is to make a /opt/sas/emi directory)
```bash
$ mkdir <somewhere>
$ cd <somewhere>
$ git clone https://gitlab.sas.com/emidev/viya-init.git
$ cd viya-init/server
```
#### To install and run as a system service (ONLY OPTION at present)
You are in the "server" subdirectory, Right?
```bash
$ sudo -u sas ./emi-service-init.sh
```
  or, to enable ETLs also
```bash
$ sudo -u sas ./emi-service-init.sh  --etl
```

After the script is complete, check the output for errors.

This will install service scripts in /etc/init.d, will install related .start scripts in /opt/sas/<deployid>/home/lib, and will invoke the "start" operation for each of
* sas-viya-metric-sub-default
* sas-viya-log-sub-default
* sas-viya-watch-consul-default

optionally
* sas-viya-metric-etl-default

## Directories

The optional SAS ETL datasets land in
* /opt/sas/viya/config/var/lib/evmsvrops/ETL/properties/

The logs and PID files land in conventional places:
* /var/run/sas/sas-viya-*-sub-default.pid
* /var/log/sas/viya/sas-*-sub/default/
* /var/log/sas/viya/sas-metric-etl/default/

## Updating an existing installation of the Monitoring ETL Initialization
If you have previously created a clone of the `viya-init.git` repository and have installed
and started the monitoring and ETL services, you can update this code by simply pulling changes
from the main repository and then rerun the `emi-service-init.sh` script. As before
```bash
$ cd <yourexistingrepo>
$ cd viya-init/server
$ sudo -u sas ./emi-service-init.sh
```
  or, to enable ETLs also
```bash
$ sudo -u sas ./emi-service-init.sh  --etl
```
The script is smart enough to stop any running service instances, will then copy new
code to the appropriate places and will start the new service instances.
