/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
  | Name:     create_shiftmap.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Creates sas table evdm.shiftmap
  |           2. Creates SHIFT type formats in SASFormats dir
  |
  |
  | Inputs    
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
data evdm.shiftmap;
  length desc id $20;
  format start stop timeampm.;
  do dow=1 to 7;
    if (dow gt 1) and (dow lt 7) then do; /* weekdays */
      id   ="2";
      desc ="OFFHOUR";
      start="00:00"t;
      stop ="09:00"t;
      output;

      id   ="1";
      desc ="PRIMETIME";
      start="09:00"t;
      stop ="17:00"t;
      output;

      id   ="2";
      desc ="OFFHOUR";
      start="17:00"t;
      stop ="24:00"t;
      output;

    end; /* weekdays */
    else do; /* weekends */
      id   ="3";
      desc ="WEEKEND";
      start="00:00"t;
      stop ="24:00"t;
      output;
    end;/* weekends */
  end; /* dow loop */
run;

%makeshiftfmt(data=evdm.shiftmap,    
              fmtname=SHIFT,    
              fmtname2=SHIFTTXT,
              fmtname3=SHIFT2TXT, 
              fmtname4=SHIFTXT2ID,
              lib=EVDMFMTS);

/* ******************************
data testFormat;
 format timestamp datetime20. time time.;

  do timestamp = "01JAN2013:00:01"dt to "10JAN2013:23:50"dt by (60*60);

     dow=weekday(datepart(timestamp));
     time=timepart(timestamp);
     in4shift=dow+(time/100000);
     shift2=put(weekday(datepart(timestamp))+((timepart(timestamp))/100000),shift.);
     shift=put(in4shift,shift.);
     shifttxt=put(in4shift,shifttxt.);
     txtSHIFT=put(shift,$shift2txt.);
     id=put(shifttxt,$shiftxt2id.);
     output;
 end;

 in4shift=.;
 shift=put(in4shift,shift.);
 shifttxt=put(in4shift,shifttxt.);
 txtSHIFT=put(shift,$shift2txt.);
 id=put(shifttxt,$shiftxt2id.);
 output;

 in4shift=0;
 shift=put(in4shift,shift.);
 shifttxt=put(in4shift,shifttxt.);
 txtSHIFT=put(shift,$shift2txt.);
 id=put(shifttxt,$shiftxt2id.);
 output;

 in4shift=8;
 shift=put(in4shift,shift.);
 shifttxt=put(in4shift,shifttxt.);
 txtSHIFT=put(shift,$shift2txt.);
 id=put(shifttxt,$shiftxt2id.);
 output;

run;
********************** */
