/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



/*+----------------------------------------------------------------+
  | Name:     SASCode/etl_driver.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Main processing of ETLs
  |
  |
  | Inputs    Everything in <evdmpath>/<datamart>
  |
  |
  | History:  Date    action
  |           05AUG17 Initial Coding                           sasgzs
  |
  | Future:
  | End
  +----------------------------------------------------------------+*/

/* Initialize the status file       */
%ev_status_summary(phase=start);

%jobheader(jobname=etl_driver);

/* ATTEMPT TO LOCK THE DATA MART;   */
/* ABORT IF LOCK CANNOT BE OBTAINED */
%datamartlock(action=LOCK,abortonfail=Y);


/* check data mart is initialized   */
%confirm_datamart_init(abortonfail=Y);


/* ATTEMPT TO CONNECT TO CAS;       */
/* ABORT IF CONNECTION FAILS.       */
%get_cas_session(abortonfail=Y);

/* ************************ */
/*  METRIC EVENT PROCESSING */
/* ************************ */
%jobheader(jobname=etl_driver,stepname=METRICS);
%etl_driver(resourcecategory=metric,
            cas_update=&emi_cas_load_metrics,
            canary_lib=&caslib_metric_data,
            canary_table=SYSTEM, 
            initjob=rolloff.sas,
            exitonfail=N); 

/* Append metric data to the status file       */
%ev_status_summary(phase=update,type=Metric);

/* ************************ */
/*   LOG EVENT PROCESSING   */
/* ************************ */
%jobheader(jobname=etl_driver,stepname=LOGS);
%etl_driver(resourcecategory=log,
            cas_update=&emi_cas_load_logs,
            canary_lib=&CAS_SEARCH_CASLIB,
            canary_table=&CAS_SEARCH_IDXNAME,
            initjob=init_lumberyard.sas,
            exitonfail=Y);

/* Append log data to the status file       */
%ev_status_summary(phase=update,type=Log);

%jobheader(jobname=etl_driver,stepname=FINISHING);

/* Append endtime and max RC to the status file       */
%ev_status_summary(phase=end);

/* Close any existing CAS session */
%exit_cas_session();

/* RELEASE THE LOCK ON THE DATA MART   */
%datamartlock(action=RELEASE, abortonfail=Y);
