
/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     SASCode/rolloff.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Reloads all data for the defined retention window.
  |           This is "functionally equivalent" to  rolling off "old"
  |           data.
  |
  | Inputs    Raw TSVs (log events) & PROCESSED TSVs (metric events)
  |
  |
  | History:  Date    action
  |           05SEP17 Major Revision to call new %ADHOC_LOAD    sasgzs
  |
  | Future:
  | End
  +----------------------------------------------------------------+*/

/*                                                                  */
/* Only update the status file if this is the rolloff job, and NOT  */
/* if it is etl_driver calling the rollof job.                      */
/*                                                                  */

%let pgm=%substr(%scan(&sysprocessname,1,/,b),1,%eval(%index(%scan(&sysprocessname,1,/,b),.sas) -1));
 %if &pgm = rolloff %then %do;

  /* Initialize the status file       */
  %ev_status_summary(phase=start);
 %end;

/* ATTEMPT TO LOCK THE DATA MART;   */
/* ABORT IF LOCK CANNOT BE OBTAINED */
%datamartlock(action=LOCK,abortonfail=Y);


/* check data mart is initialized   */
%confirm_datamart_init(abortonfail=Y);


%rolloff;
 %if &pgm = rolloff %then %do;
    /* write out status summary */
    %ev_status_summary(phase=update,type=Metric);
 
 
    /* Append endtime and max RC to the status file       */
    %ev_status_summary(phase=end);
 %end;

 /* RELEASE THE LOCK ON THE DATA MART   */
 %datamartlock(action=RELEASE, abortonfail=Y);

