/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/


 /*+----------------------------------------------------------------+
  | Name:     addshiftvar.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Adds variable SHIFT to SAS table
  |
  |
  | Inputs    SAS table (metrics)
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro addshiftvar(datetime=datetime,    /* name of the variable containing the datetime value */
                   outvar=shift,         /* name of variable to contain unformatted shift value */
                   shiftfmt=shifttxt,    /* name of the format to assign the variable */
                   label=%str(Work Shift (based on local time)), /* label to assign to new variable */
                   offsetvar=tzoneoff,   /* name of the variable containing the timezone offset */
                   prefixvar=,           /* FUTURE: will be used to support multiple SHIFT schemes */
                   form=SQL);            /* form of SAS statement (DATASTEP or SQL) to generate */
                   
 %if "&form" eq "SQL" %then
 %do; /* generate SQL statements */
    case
     when(&datetime eq .) then .
     else weekday(datepart(sum(&datetime,&offsetvar)))+((timepart(sum(&datetime,&offsetvar)))/100000)  
    end format &shiftfmt.. label "&label" as &outvar

 %end;/* generate SQL statements */
 %else
 %do; /* generate DATA STEP statements */
 
     attrib &outvar format=&shiftfmt.. label="&label";

     if &datetime eq . then &outvar=.;
     else &outvar = weekday(datepart(sum(&datetime,&offsetvar)))+((timepart(sum(&datetime,&offsetvar)))/100000) ;     

 %end;/* generate DATA STEP statements */
 
%mend addshiftvar; 