/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     alerts.sas                                           |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Misc utility                                         |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAy17 Initial Coding                        frefor |
   |                                                                |
   |                                                                |
   +----------------------------------------------------------------+*/

%macro alerts(resourcetype=,);
filename alerts "/dept/fitforit/Internal/greyhoundETL/Alerts/&resourcetype..json";
libname  alerts "/dept/fitforit/Internal/greyhoundETL/Alerts/";
%global metricname testoperator warningvalue criticalvalue;

/*                                                             */
/* Get resource properties                                     */
/*                                                             */

data prop_&resourcetype ;set resourceproperties;
  where lowcase(resourcetype)="&resourcetype" and lowcase(propertyname) in ('dirname','systypename');
run;
proc sort data=prop_&resourcetype ;by resourceid;
run;
proc transpose data=prop_&resourcetype  out=trans_&resourcetype (drop=_name_);by resourceid;
  id propertyname;
  var propertyvalue;
run;







data definitions;set alerts.&resourcetype._definition;
 where lowcase(resourcetype) = "%lowcase(&resourcetype)";
   call symput('warningvalue',warningvalue);
   call symput('criticalvalue',criticalvalue);
    call symput('testoperator',testoperator);
run;
data alerts_&resourcetype;set staging.&resourcetype;
  length message $230.;
  length checkstatus $8.;
  /*
  keep testoperator  units   warningvalue criticalvalue     metricname  level message checkstatus
                version programversion detailsversion  source  name program  detailstype  resourcetype ;
     *     timestamp=put(datetime(),e8601Dx32.6);
           timestamp=put(datetime,e8601Dx32.6);
  */
  if available=0 then return;
  metricvalue=100*(free/size);
   if metricvalue &testoperator &warningvalue then do;
      message='Low disk space on ' || left(trim(resourceid));
      checkstatus='WARN';
     if metricvalue &testoperator &criticalvalue then do;
        checkstatus='CRITICAL';
     end;
    set definitions;
    output;
   end;
run;

PROC sorT data=alerts_&resourcetype;
  by resourceid;
run;
data alerts_&resourcetype;
 merge alerts_&resourcetype (in=in1) trans_&resourcetype (in=in2);
  by resourceid;
  if in1 & in2;
run;

data _null_;set alerts_filesystem;
        file alerts;
        put '{'
                /       '"version":' version ','
                /       '"timestamp":"' timestamp +(-1) '",'
                /       '"level":"' LEVEL +(-1) '",'
                /       '"name":"' name +(-1) '",'
                /       '"message":"' message +(-1) '",'
                 /   '"source":"' source +(-1) '",'
                /       '"properties":{'
                /               '"program":' '"' program +(-1) '"' ','
                /               '"programVersion":' '"' programversion '"},'
                /       '"detailsType":' '"' detailstype +(-1) '",'
                /       '"detailsVersion":'  detailsversion +(-1) ','
                /       '"details":{'
                /               '"thresholds":['
                /                       '{'
                /                               '"checkStatus":"' checkstatus +(-1) '",'
                /                               '"resourceType":"' resourcetype +(-1) '",'
                /                               '"resourceId":"' resourceid +(-1) '",'
                /                               '"metricName":"' name +(-1) '",'
                /                               '"metricValue":' metricvalue 8.2 +(-1)  ','
                /                               '"units":"' units +(-1) '",'
                /                               '"testOperator":"' testoperator +(-1) '",'
                /                               '"warningValue":' warningvalue 8.2 +(-1)  ','
                /                               '"criticalValue":' criticalvalue 8.2 +(-1)  ','
                /                               '"properties":{'
                /                                       '"fileSysType":"' systypename +(-1) '",'
                /                                       '"mountPath":"' dirname +(-1) '"'
/
/                                                       '}}]}}';
run;

%mend alerts;
