/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     appendSASTable.sas                                   |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Appends SAS data set to CAS table                    |
   |                                                                |
   | History:  Date    action                                       |
   |           17MAR17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   

 
%macro appendSASTable(out_caslib=,             /* CASLIB of target CAS table */
                      out_table=,              /* name of target CAS table */
                      data=,                   /* name of source SAS data set (1 or 2 level) */
                      dsoptions=%str(obs=max), /* any data set options to apply to source table*/
                      mode=append) ;           /* mode (APPEND|REPLACE|PROMOTE) */


   %emimacroinit();

   
   /* ************************** */
   /*    TO BE DETERMINED        */
   /* local table + append = ?   */
   /* local table + replace = ?  */
   /* local table + promote = ?  */
   /* global table + append = ?  */
   /* global table + replace = ? */
   /* global table + promote = ? */
   /*                            */
   /* Split mode? e.g. need new  */
   /*    arg for replace?            */
   /* ************************** */
  
   proc cas;
    %tableExists(caslib=&out_caslib,table=&out_table);
   
    if rc eq 1 and %upcase("&mode") eq "PROMOTE" then
    do; /* attempting to promote an existing table  */
  
        /* !!! DO WE WANT TO DO THIS?  OR SHOULD WE FAIL? !!! */
        %dropTable(caslib=&out_caslib,table=&out_table);
       
    end;/* attempting to promote an existing table  */
    if rc eq 2 and %upcase("&mode") eq "REPLACE" then
    do; /* global table to be replaced */
  
        %dropTable(caslib=&out_caslib,table=&out_table);
       
    end;/* global table to be replaced */
   quit;
  
   proc casutil outcaslib=&out_caslib ;
    load data=&data(&dsoptions) casout="&out_table" &mode;
   quit;
   
%mend appendSASTable;
