/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/


 /*+----------------------------------------------------------------+
  | Name:     build_view.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Builds a view of the output TSV file. One view per resourcetype
  |           per day. Note - The view only needs to be built once per day.
  |           
  |
  | Inputs    resource
  |           date
  |			  path to view 
  |
  | History:  Date    action
  |           19Apr17 Initial Coding                              frf
  | Future:
  | End
  +----------------------------------------------------------------+*/

%macro build_view(resourcetype=,file=,);
data ETL_vars; set sashelp.vcolumn(keep=libname memname name length type);	
	 where lowcase(libname)='work' and lowcase(memname) = "&resourcetype"; 
run;

data _NULL_;set ETL_vars end=last ;by memname;
  length vars init_vars lengths $4096.;
   retain vars init_vars lengths ;
   
   /*                                                   */
   /*  Build macro variables whose value will be a list */
   /*  of variable names contained in the persistent    */
   /*  tables. For example                              */
   /*                                                   */
   /* SYSTEM_V0='resourcetype' '09'x   'resourceid' '09'x 'deploymentid' '09'x */
   /* SYSTEM_V=resourcetype resourceid deploymentid  */
   /*                                                   */
   /* These macro variables are used in PUT statements, */
   /* 	PUT SYSTEM_V0 (for headers in the TSV)  or   */
   /*   PUT SYSTEM_V to output the variable values.  */
   /*                                                   */
  
   if first.memname then do;   
   	vars=' ';
   	init_vars=' ';  
   	lengths=' ';
   end;
   
   	if type='char' then dollar=' $ ';else dollar=' ';
   	
   	if left(trim(lowcase(name))) = 'shift' then do;
   		dollar =' $ ';
   		length=16;
   	end;
   	
       vars=left(trim(vars)) || " " || left(trim(name)) ;
       lengths=left(trim(lengths)) || " " || left(trim(name)) || dollar || left(trim(length));; 
       init_vars=left(trim(init_vars)) || " '" || left(trim(name)) || "'" || " '09'x" ;
	   
          if last.memname then do;
           var=compress(memname || '_v');
           var_length=compress(memname || '_l');
           init_var=compress(memname || '_v0');
             vars=trim(vars) || ";" ;
             lengths=trim(lengths) || ";" ;
              call symput(var,vars);
              call symput(var_length,lengths);
			  call symput(init_var,init_vars); 
			 output;
          end;
run;

%put in build_view file=&file;
%let last_slash=%scan(&file,-1,/);
%let tsv_file_date=%substr(&last_slash,1,8);

 

data rt.view_&tsv_file_date /view=rt.view_&tsv_file_date;
 
  	drop  dir file date version ;
	 length version $16. date $8.;		
	
	dir=symget('path_to_view');
	version=symget('tsv_file_version');
	date=symget('tsv_file_date');	
	dir=compress(dir);		
	
	file=compress(date || '-' ||
		 version || '-PROCESSED.tsv');		
	
	dir1=compress(dir || file);		
	
		 	length &&&resourcetype._l;
			
 			infile foo filevar=dir1 firstobs=2 dlm='09'x dsd missover;	
						
			   input &&&resourcetype._v;			  	   
run;

%mend build_view;




