/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     caspromote.sas                                       |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose: Promotes a CAS table to global scope.                 |
   |                                                                |
   | History:  Date    action                                       |
   |           11MAY17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   
%macro caspromote(caslib=,table=,outcaslib=,outtable=,replace=Y,drop=N);
  
  %if "&outcaslib" eq "" %then %do; %let outcaslib=&caslib;%end;
  %if "&outtable" eq "" %then %do; %let outtable=&table;%end;
  
  %local drop_str;
  
  %if "&drop" eq "N" %then
  %do;
     %let drop_str=%str(drop=FALSE);
  %end;
  %else
  %do;
     %let drop_str=%str(drop=TRUE);
  %end;
  
  %if ("&outcaslib" eq "&caslib") and ("&outtable" eq "&table") %then
  %do; /* source and target match */
 
     /*  don't drop table before promoting it */
     %let drop_str=%str(drop=TRUE);
     %let replace=N;   
     
  %end;/* source and target match */
 
  %if "&replace" eq "Y" %then
  %do; /* delete if table exists */
 
      %droptable(caslib=&outcaslib,table=&outtable);
      
      /* returns -1 if table does NOT exist */
      /*         0 if drop was successful   */
     
  %end;/* delete if table exists */
  %else %if "&replace" eq "N" %then
  %do; /*check if output table already exists */
 
     %tableExists(caslib=&outcaslib,table=&outtable);
     
     /* returns 1 if table exist w/session scope */
     /*         2 if table exist w/global scope  */
     /*         0 if table does not exit         */
    
  %end; /*check if output table already exists */
  %else  rc=0;
  
  if rc le 1 then
  do; /* continue to PROMOTE */
  
     action table.promote result=results status=s;
     param caslib="&caslib" name="&table"
           &drop_str 
           target="&outtable" targetLib="&outcaslib";
           
    %check_results(results=results,status=s, message='Promoting table');
    
  end;/* continue to PROMOTE */
  else 
  do; /* something is wrong */
     
      /* return code will be non-zero */
     
  end;/* something is wrong */
 
%mend caspromote;

