/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     check_version.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Checks to see if a version number exists in evdm_versions 
  |
  |
  | Inputs    evdm_versions
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro check_version(version=,major=,minor=,patch=,resource_category=, resourcetype=, type=input);

 %let evdmerr=N;

 %local where;
 
 %if "&version" ne "" %then %let where=%str(evdm_version="&version" and);
 %else %let where= %str(version_major eq &major and version_minor eq &minor and version_patch eq &patch and);

 %let known_version=0;

 %if %sysfunc(exist(EVDM.EVDM_VERSIONS)) %then
 %do;
    proc sql noprint;
     select count(*)
      into :known_version
       from evdm.evdm_versions
        where &where
              type eq "&type" and
              resource_category eq "&resource_category" and
              resource eq "&resourceType";
    quit;
 %end;

 %if &known_version gt 0 %then
 %do; /* known file version */
    %put %str(INFO: A file format exists that can process this file);
    %return;
 %end;/* known file version */
 %else
 %do; /* unknown version */

    %findfiles(dir=&evdmpath,namematchrx=headers-&version.\.tsv,outds=work._files);
   
    %local header2load;
   
    proc sql noprint;
     select logfile
      into :header2load
       from work._files;
    quit;
   
    %if "&header2load" ne "" %then
    %do; /* parse the newly found header file */
       %parse_header(file=&evdmpath/&header2load,out=evdm.evdm_versions,append=Y);

       %if "&EVDMERR" eq "Y" %then
       %do; /* called macro return an error; exit */
          %put %str(WARNING: Call to PARSE_HEADER failed; exiting CHECK_VERSION macro);
          %goto EXIT_ERR;
       %end; /* called macro return an error; exit */

    %end;/* parse the newly found header file */
    %else
    %do; /* no matching header found */
   
      %put %str(WARNING: No header information was found for this version [&version]);
      %goto EXIT_ERR;
      
    %end;/* no matching header found */
      
 %end;/* unknown version */

 %return;

 %EXIT_ERR:

 %let evdmerr=Y;
 %return; 
   
%mend check_version;
