/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     ck4newvals.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Checks to see if any new data added to a CAS table
  |
  |
  | Inputs    CAS tables
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/

%macro ck4newvals(var=source, length=200, data=, masterlib=, mastertable=) ;

 %local rc;
 %local promote;

 libname _tmpclib cas caslib=CASUSER;
     
 proc cas;
  %tableExists(caslib=&masterlib, table=&mastertable);
  if rc then call symputx("RC","1","F");
  else call symputx("RC","0","F");
 quit;

 /* suppress printed output */
 ods exclude all; 

 proc cas;
  simple.freq /
   casOut={caslib="CASUSER",name="SOURCESNOW",replace=true}
   table={caslib="&masterlib",name="&data",
   vars={{name="&var",format="$",formattedLength=&length}}};
  run;
  quit;
 

 %if "&rc" eq "1" %then
 %do; /* cas table exists */

     proc cas;
      simple.freq /
       casOut={caslib="CASUSER",name="SOURCESKNOWN",replace=true}
       table={caslib="&masterlib",name="&mastertable",
       vars={{name="&var",format="$",formattedLength=&length}}};
      run;
     quit;



    proc sql noprint;   
     create table __somevalues as    
      select _charvar_ length=&length as &var
       from _tmpclib.SOURCESNOW
        where _charvar_ not in(select _charvar_ length=&length
                             from _tmpclib.SOURCESKNOWN);  
    quit;  

 

 %end;/* cas table exists */
 %else
 %do; /* master table does NOT exist */

    proc sql noprint;   
     create table __somevalues as    
      select _charvar_ length=&length as &var
       from _tmpclib.SOURCESNOW;
    quit;  
   
    %let promote=promote;  /* need to promote the new CAS table */

    %put NOTE: The specified master list [&masterlib..&mastertable] of [&var] values does not exist%str(;) it will be created.;
  
 %end;/* master table does NOT exist */
   
 %if &sqlobs gt 0 %then
 %do; /* append new values to masterlist */

    proc casutil outcaslib=&masterlib ;
     load data=work.__somevalues casout="&mastertable" append &promote;
    quit;
 
    %put NOTE: New values for variable [&var] were found%str(;) the master list [&masterlib..&mastertable] was updated to include these [&sqlobs] new values.;
    
 %end;/* append new values to masterlist */ 
 %else %put NOTE: No new values for variable [&var] were found%str(;) the master list [&masterlib..&mastertable] was not updated.;;

 proc cas;
  %droptable(caslib=CASUSER,table=SOURCESNOW);
  run;
  %droptable(caslib=CASUSER,table=SOURCEKNOWN);
  run;
 quit;

 libname _tmpclib clear;

 /*re-enable ODS output */    
 ods exclude none;

%mend ck4newvals;


