/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     confirm_datamart_init.sas                            |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Performs a number of checks to confirm that the      |
   |           current data mart has been properly initialized.     |
   |                                                                |
   | Return Codes:                                                  |
   |                                                                |
   |   Value | Meaning (related action)                             |
   |  -------+----------------------------------------------------- |
   |         | None defined here at this time; but called programs  |
   |         | can also terminate session and set a return code.    |
   |                                                                |
   |                                                                |
   | History:  Date    action                                       |
   |           28JUL17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/

%macro confirm_datamart_init(abortonfail=N);

 %local error_code;

 %confirm_sas_table_init(libname=evdm,table=shiftmap,
                         initjob=create_shiftmap.sas,
                         abortonfail=&abortonfail);

 %confirm_sas_table_init(libname=evdm,table=whitelist,
                         initjob=create_whitelist.sas,
                         abortonfail=&abortonfail);

 %if &error_code gt 0 %then %goto EXIT_ERROR;

%EXIT:
  %return;
 
%EXIT_ERROR:
  %if %upcase("&abortonfail") eq "Y" %then %goto EXIT_ABORT;     
  %return;

%EXIT_ABORT:
  %datamartlock(action=RELEASE); /* release lock on data mart if it exists */
  %put %str(ERROR: Terminating session because the data mart initialization validation check failed (rc=[&error_code]).);
  %abort return &error_code;
  %return;

%mend confirm_datamart_init;


