/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     delete_files.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Delete files from a directory with a modification date
  |              older than X days with a given file extension.  
  |
  | Inputs    directory to delete, extension, cutoff date
  |           
  |
  | History:  Date    action
  |           08Aug17 Initial Coding                              frf
  | Future:
  | End 
  +----------------------------------------------------------------+*/
%macro delete_files(dir=,		  /* Directory from which to delete files */
					cutoff=,      /* Delete files older than CUTOFF days  */
					extension=,); /* Extension of the file(s) to delete.  */

		%findfiles(dir=%cmpres(&dir), 
        	     outds=work._foundfiles, 
        	     namematchrx=.*\.&extension [ ] ) ;        
		
	/*                                                      */
	/* Delete any file older than CUTOFF                    */
	/*                                                      */
		
	   data _null_;set _foundfiles;
	    length file_to_delete $256.;
				if today() - datepart(modfdt) gt &cutoff then do;
					file_to_delete=compress(directory || '/' || logfile);
					fname="tempfile";
					 rc=filename(fname,file_to_delete);
					 if rc=0 then rc=fdelete(fname);
					 rc=filename(fname);
				end;
		run;
%mend delete_files;

			
