/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     drop_cas_tables.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Drops cas tables
  |
  |
  | Inputs    dataset containing tables to drop
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro drop_cas_tables(tablelistds=,  /* data set containing list of tables to drop */
                       where=,        /* (optional) WHERE clause (w/o WHERE) to apply to table */
                       table_var=,    /* data set variable identifying table to be dropped */
                       caslib_var=,   /* (optional) data set variable identifying CASLIB from which table should be dropped */
                       caslib=);      /* name of CASLIB from which tables should be dropped, if CASLIBNMVAR eq NONE */

 %local caslib_str where_clause;
 
 %if "&caslib_var" ne "" %then %let caslib_str=%str(, &caslib_var);
 %else %let caslib_str=%str(, "&CASLIB" as foo);
 
 %if "&WHERE" ne "" %then %let where_clause=%str(WHERE &where);
 
 proc sql noprint;
  select distinct &table_var
   &caslib_str
   into :table1-:table999, 
        :caslib1-:caslib999
    from &tablelistds
     &where_clause;
 quit;
 
 %let tablecount=&sqlobs;
 
 %if &tablecount lt 1 %then
 %do; /* no tables found */
    %put %str(NOTE: No)
    return;
 %end;/* no tables  found */
 
 %get_cas_session();
 
 proc cas;
 
 %local i;
 
 %do i = 1 %to &tablecount;
 
   %droptable(caslib=&&caslib&i,table=&&table&i)
   run;  
   put "DEBUG: Drop of [&&caslib&i...&&table&i] returned [" rc "]";
 %end; /*i-loop */

 quit;
 
%mend drop_cas_tables;
 
