/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     ev_ledger_evt.sas                                    |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Misc utility                                         |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAy17 Initial Coding                        frefor |
   |                                                                |
   |                                                                |
   +----------------------------------------------------------------+*/

%macro ev_ledger_evt(ds=,out=,jobid=,startTime=,endTime=,host=&evhost,siteId=,datamartId=);

%let dataset = work._EVSCRATCH;
         
  %local mname outstmt;
  %let mname=ev_ledger_evt;
  %if "&out" ne "" %then %do;
     %if "%upcase(&out)" eq "STDOUT" %then %let outstmt=%str(out=STDOUT);
     %else %let outstmt=%str(out="&out");
  %end;
  %else %do;
      %everrmsg(&MNAME,msg=Missing proc json out file or fileref consider STDOUT);
      %goto EXIT;
  %end;
  %if &evdebug gt 1 %then %do;
     %put (&MNAME) out=&out;
     %put ds=&ds;
     %put siteId=&siteId;
     %put datamartId=&datamartId;
  %end; 
  
  %if "&ds" EQ "" %then %do;
  	%everrmsg(&MNAME,msg=Missing Dataset);
  	%goto EXIT;
  %end;
  %else %do;
	%let _dsid = %sysfunc(open(&ds.));
     %let cpnobs = %sysfunc(attrn(&_dsid,NOBS));           
     %if "&cpnobs" EQ "0" %then %do;
         %let rc = %sysfunc(close(&_dsid));
         %everrmsg(&MNAME,msg=Dataset [&ds] has 0 observations);
         %goto EXIT;
      %end;
      /* put max obs test in */
      %let rc = %sysfunc(close(&_dsid));  
  %end;
  
  %if "&endTime" eq "" %then %do;
  	%let endTime=%sysfunc(putn(%sysfunc(tzones2u(%sysfunc(datetime()))),E8601dz32.6));
  %end;
  %if "&startTime" eq "" %then %do;
  	%let startTime=%str(unknown);
  %end;
  
  proc json &outstmt. pretty nosastags ;
    write open object;
      write values "version" 1;
      write values "startTime" "&startTime";
      write values "endTime" "&endTime";
      write values "properties";
      write open object;
         write values "deploymentId" "&HOST";
         write values "datamartId" "&datamartId.";         
      write close;     
      write values "customer";
      write open object;
         write values "siteId" "&siteId";
      write close;
      write values "items";
      write open array;
         export &ds.;
      write close;
   write close;
  run;
  
  %EXIT:
%mend ev_ledger_evt;
