/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/


 /*+----------------------------------------------------------------+
  | Name:     ev_status.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Writes status of ETL operations to dm.metrics file for
  |                       each category(transform, CAS)
  |
  | Inputs    evdm.evdm_versions
  |
  |
  | History:  Date    action
  |           09Jun17 Initial Coding                              frf
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro ev_status2(phase=,
                                  status=,
                                  category=,);

%global max_etlhealth;
        filename etlstats '/opt/sas/viya/config/var/lib/emi/evdm/dm.metricsf';
        
        %if %lowcase(&phase) = initialize %then %do;
                %let rc=%sysfunc(fdelete(etlstats));
             *   filename etlstats '/opt/sas/viya/config/var/lib/emi/evdm/dm.metricsf';
				%let max_etlhealth=unknown;
        %end;
	

        /*                                              */
        /* category                                     */
        /*   - transform                                */
        /*       read TSV, calculate rates, output TSV. */
        /*   - CAS                                      */
        /*       signon, append, promote                */
        /* phase                                        */
        /*   -inititalize                               */
        /*   -finished                                  */
        /* status                                       */
        /*   -unknown (beginning)                       */
        /*   -complete                                  */
        /*                                              */


data _null_;
        length category phase $32 status etlhealth max_etlhealth $8.;
        category=symget('category') || 'rc';
        phase=symget('phase');
        status=symget('status');        

                if lowcase(phase)='initialize' then do;
                        start=put(datetime(),e8601dx.);
                        etlhealth=status;
                     
                        file etlstats ;
                        put 'etlhealth=' etlhealth '(initializing)' /
                                'laststarttime=' start;
                                
                               call symput('max_etlhealth','unknown');
						
                end;

                if lowcase(status) = 'unknown' then do;
                        file etlstats mod;
                        put category '=' status '(initializing)';
                end;

                 else if lowcase(status) = 'complete' then do;                      
                        syscc=symget('syscc');
                        sysrc=symget('sysrc');
                        rc=max(syscc,sysrc,abs(&syslibrc));
                        max_etlhealth=max(syscc,sysrc,&max_etlhealth,abs(&syslibrc));						
						call symput('max_etlhealth',max_etlhealth);
                       
                        /*                                                  */
                        /* Update the last record in etlstats               */
                        /*                                                  */

                        file etlstats mod;
                        put category '=' rc '(final resolution)';

                 end;
                
                 if lowcase(phase)='finished' then do;                        
                        end=put(datetime(),e8601dx.);
                        syscc=symget('syscc');
                        sysrc=symget('sysrc');					
                        etlhealth=symget('max_etlhealth');
                      
                        file etlstats mod;
                        put 'etlhealth=' etlhealth '(final resolution)' /
                                'lastendtime=' end;
                end;
              

run;
%put after datastep max_etlhealth=&max_etlhealth;
                        %let syscc=0;
                        %let sysrc=0;
						%let syslibrc=0;
filename etlstats clear;

%mend ev_status2;


options nomprint nosgen nomlogic;



%ev_status2(phase=initialize,category=transform,status=unknown);
%put max_etlhealth=&max_etlhealth;;
data crap1;
        x=1;
run;
%put _max_etlhealth=&max_etlhealth;;
%ev_status2(category=transform,status=complete);
%put max_etlhealth=&max_etlhealth;;
%ev_status2(category=CAS,status=unknown);
libname xx 'C:\okokokokf';
data crap2 ;set crap1;
       *where r=1;
run;
%put max_etlhealth=&max_etlhealth;;

%ev_status2(category=CAS,status=complete);
%ev_status2(phase=finished);
%put max_etlhealth=&max_etlhealth;




