/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/


 /*+----------------------------------------------------------------+
  | Name:     ev_status_summary.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Summarizes the ETL execution return codes
  |           
  |
  | Inputs    work.ev_status
  | 
  |
  | History:  Date    action
  |           12May17 Initial Coding                              frf
  |           16May17 Read from WORK instead of evdm              frf
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro ev_status_summary(phase=,type=,);

/*                                                */
/* Return if the ev_status table does not exist.  */
/*                                                */

	%if %sysfunc(exist(work.EV_STATUS)) =0 and &phase = update %then %do;
		%put Note: work.ev_status does not exist;
		%put Exiting ;
		%return;
	%end;



/*                                                   */
/* Get start time and write (initialize) status file.*/
/*                                                   */

	%if %lowcase(&phase) = start %then %do;
	
	/*                                                */
	/* Call get_status_filename to assign a fileref   */
	/* to write to.                                   */
	
	%get_status_filename(fref=etlstats);
	
	%end; /* initialize etlstats file */
	
	%else %if %lowcase(&phase) = end %then %do;
	
	    /*                                                         */
		/* Find highest RC for this all phases. The first obs will */
		/* be the highest RC.                                      */
		/*                                                         */
		
	 %if %sysfunc(exist(work.max_rc)) %then %do; 	
	  proc sort data=max_rc(keep=rc) ;by descending rc;
	  run;
	  
		data _null_;set max_rc end=last;
			call symput('overall_rc',rc);
			stop;
		run;
	 %end; /* max_rc exists */
	
	 %else %do; 
	  %let syslibrc=%sysfunc(abs(&syslibrc));
	  %let overall_rc=%sysfunc(max(&syscc,&sysrc,&syserr,&sysinfo,&syslibrc));
	 %end; /* max_rc does not exists */
		
		/*                                                         */
		/* Keep track of highest RC for this phase (logs, metrics) */
		/* and append to the status file.                          */ 
		/*                                                         */
		
		data _null_;
			file etlstats mod;
			 length max_rc $8. ;			 
			 max_rc=compress(symget('overall_rc'));	 
			 				
				put 'statusRC=' max_rc   ;
		run;		
	%end; /* finalize etlstats file */
/*                                                */
/* Summarize by category  .                       */
/*                                                */

	%else %if %lowcase(&phase) = update %then %do;
		
		data ev_status;set ev_status;
			LENGTH MAX_rc_source $9. ;
			rc=max(syscc,sysrc,sysinfo,syserr,syslibrc);
				if syscc=RC then max_rc_source='_SYSCC';				 
				 else if sysrc=RC    then max_rc_source='_SYSRC';
				 else if sysinfo=RC  then max_rc_source='_SYSINFO';
				 else if syserr=RC   then max_rc_source='_SYSERR';
				 else if syslibrc=RC then max_rc_source='_SYSLIBRC';				
		run;
		
		proc sort data=work.ev_status out=ev_status;by action rc;
		run;
		
		data ev_status_summary;set ev_status;by action;
			keep action rc max_rc_source ;			
			if last.action then output;
		run;
		
		/*                                                */
		/* Get overall (highest) rc.                      */
		/*                                                */

		proc sort data=ev_status(keep=rc) out=rc;by descending rc;
		run;
		
		data this_rc;set rc ;
		  call symput('osRC',rc);
			output;
			stop;
		run;
		
		/*                                                         */
		/* Keep track of highest RC for this phase (logs, metrics) */
		/*                                                         */ 
		
		proc append data=this_rc base=max_rc;
		run;
		
		/*                                                */
		/* Write report.                                  */
		/*                                                */

		data _null_;set ev_status_summary end=last;
		  length osRC 8.;
			file etlstats mod;		
			put action + (-1) max_rc_source + (-1) 'RC=' rc;
				if last then do;
					osRC=compress(symget('osRC'));
					type=compress(symget('type'));
					
					if osrc=0 then osRC=0; 
					else if osrc le 4 then osRC=1;
					else if osrc gt 4 then osRC=2;
					put 'os' type + (-1) 'RC=' osRC;
				end;
		
run;

		%if %sysfunc(exist(work.EV_STATUS)) %then %do;
			proc datasets lib=work nolist;
			delete ev_status;
			quit;
		run;
		%end; /* Delete the ev_status file  */
	%end; /* Updating etlstats file */

%mend ev_status_summary;


