/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

%macro evavailsub(in=evdmraw.hq_avail_data,
                  out=,
                  start=,                 
                  hasDeleted=N,
                  end=datetime(),
                  measInv=acm.measureinventory);

proc sql;
 create table &out.(compress=yes) as
  select b.resource_id,

  %if %upcase("&hasDeleted") ne "Y" %then
  %do; /* need to calculate the DELETED flag */
         NOT missing (a.dtime) as deleted, 
  %end;/* need to calculate the DELETED flag */
  %else
  %do; /* the DELETED flag is already on table */
         a.deleted,
  %end;/* the DELETED flag is already on table */

         put(b.resource_id,res2name.) length=500 as name,
         put(b.resource_id,res2short.) length=500 as shortname,
         a.measurement_id,
         a.avail,
         case 
           when (a.starttime lt &start) then &start
           else starttime
          end as starttime format datetime24.,
         case 
           when (a.endtime eq .z) then &end   
           when (a.endtime gt &end) then &end
           else a.endtime
          end as endtime format datetime24.,
         (calculated endtime-calculated starttime)/60 as minutes 
    from &in a left join &measInv b on a.measurement_id eq b.measurement_id

            /* ****************************************************** */
            /* WHERE: the period starts before the specified end AND  */
            /*        [[the period ended after the specified start OR */
            /*         has not ended yet]]                            */
            /* ****************************************************** */

      where a.starttime le &end and (a.endtime ge &start  or a.endtime eq .Z)                                  
       order by resource_id, starttime, avail;
quit;

%mend evavailsub;
