/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

%macro evdatasub(data=,                   /* name of input data set */
                 out=,                    /* name of output data set or view */
                 type=VIEW,               /* type of output table (VIEW|TABLE)*/
                 dtvar=datetime,          /* name of date or datetime variable in input data set */
                 addtzoff=N,              /* flag to indicate whether to add the TZONEOFF variable to output data set */
                 addshift=N,              /* flag to indicate whether to add the SHIFT variable to output data set */
                 addshort=N,              /* flag to indicate whether to add the SHORTNAME variable to output data set */
                 addname=N,               /* flag to indicate whether to add the NAME variable to output data set */
                 start=,                  /* start of date range of interest */
                 end=MAX);                /* end of date range of interest */

/* Purpose:  This macro subsets the specified input table based on the specified date range. */
/*           The result can be either a VIEW or a DATA FILE.                                 */

proc sql;
 create &type &out as
  select *

   %if "&addtzoff" eq "Y" %then
   %do; /*calculate and add a timezone offset variable to the output data */
         ,%addtzoffvar(form=SQL,hostvar=scan(put(resource_id,res2name.),1),outvar=tzoneoff, datetime=datetime)
   %end;/*calculate and add a timezone offset variable to the output data */

   %if "&addshift" eq "Y" %then
   %do; /*calculate and add a shift variable to the output data */
         ,%addshiftvar(datetime=datetime, offsetvar=calculated tzoneoff, outvar=shift, shiftfmt=shifttxt, form=SQL)
   %end;/*calculate and add a shift variable to the output data */

   %if "&addname" eq "Y" %then
   %do; /*add the NAME variable to the output data */
         ,put(resource_id,res2name.) length=500 as name
   %end;/*add the NAME variable to the output data */

   %if "&addshort" eq "Y" %then
   %do; /*add the SHORTNAME variable to the output data */
         ,put(resource_id,res2short.) length=500 as shortname
   %end;/*add the SHORTNAME variable to the output data */


   from &data
    where &dtvar gt &start 

   %if "&end" ne "MAX" %then
   %do; /* an upper bound was specified */

       and &dtvar le &end

   %end;/* an upper bound was specified */

   ; /* do NOT delete -- this is the semi-colon to end the WHERE clause */

quit;

%mend evdatasub;