
/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     evdmsettz.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Finds offset of supplied timezone 
  |
  |
  | Inputs    timezone
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro evdmsettz(timezone=);

  %global evdmtzoffset;

  %if "&timezone" eq "" %then
  %do; /* no time zone specified */

        %let evdmtzoffset=&SYSTIMEZONEOFFSET;
                
  %end;/* no time zone specified */
  %else 
  %do; /* cal offset for specified time zone */
  
        %let evdmtzoffset=%sysfunc(tzoneoff(&timezone));
       

        %if "&evdmtzoffset" eq "." %then
        %do; /* offset is missing -- invalid time zone*/

            %put WARNING: *** EVDMSETTZ Macro - Specified timezone (&timezone) not recognized, using the value of the automatic macro variable SYSTIMEZONEOFFSET (&SYSTIMEZONEOFFSET).;

            %let evdmtzoffset=&SYSTIMEZONEOFFSET;

        %end;/* offset is missing -- invalid time zone*/
        %else
        %do; /* an apparently valid timezone has been provided */

            %local currentTZ;
            %let currentTZ=%sysfunc(tzoneid());
            
            %if "%UPCASE(&currentTZ") ne %UPCASE("&timezone") %then
            %do; /* specified timezone does not match current session timezone setting */

               %put WARNING: *** EVDMSETTZ Macro - Specified timezone (&timezone) for Data Mart does not match current SAS System OPTION setting (&currentTZ).  SAS System OPTION will be set to match Data Mart setting.;

               options timezone="&timezone";

            %end;/* specified timezone does not match current session timezone setting */

        %end;/* an apparently valid timezone has been provided */ 

  %end;/* cal offset for specified time zone */
 
  %if "&evdmtzoffset" eq "." %then
  %do; /* offset is missing */

      %put WARNING: *** EVDMSETTZ Macro - EVDM Timezone offset was missing, setting it to 0.  This could indicate a problem with the SYSTIMEZONEOFFSET automatic macro variable (&SYSTIMEZONEOFFSET).;

      %let evdmtzoffset=0;

  %end;/* offset is missing */

  %put NOTE: Set EVDM Timezone offset to &evdmtzoffset;

 %mend evdmsettz;