/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

/*---------------------------------------------------------------------------
  | NAME: evevent
  |               
  | Product:  SAS Environment Manager
  |
  | DESC: Macro to send text string to evevent msg file which is monitored by
  | the emi-commons plugin. Logfile in Events directory named sasev.events.
  |
  | Usage:
  |    msglevel  - Supports DEBUG, INFO, WARN, and ERROR. TRACE mapped to DEBUG 
  |    msgtext   - Message String
  |    src       - Source message string ( may use : keyword to help understand
  |                sub formatting in message string. Example  DSA:NVP where 
  |                NVP stands for msg string with name value pairs.  
  |    floc      - File path override to write event message. 
  |
  | Notes:
  | msgtext does not support linebreaks, src has length and msg has a length
  | using agent path with versions. hate those. 
  |          
  | UPDATED: 11Oct2013      rnb, gzs 
  |          12Nov2013      Added dt validation. Delimiter checking etc  rnb
  |           
  +------------------------------------------------------------------------*/

%macro evevent(src=,msglevel=INFO,msgtext=,floc=,debug=);
   %local mname errmsg_local fid;

   %let mname=%str(evevent);
   %let msglevel=%upcase(&msglevel);
   %let errmsg_local=%superq(syserrortext);
   %if "&debug" EQ "" %then %do;
      %if %symexist(evdebug) %then %let debug=&evdebug;
   %end;
   
   %if "&src" EQ "" %then %do;
      %put ERROR: (&MNAME), evevent requires src input value [&src];
      %goto EXIT;
   %end;

   /* hardening, sasev agent uses | as a delimiter */
   %let src = %sysfunc(translate(&src,'!','|'));
   
   %if not ("&msglevel." EQ "INFO" or
          "&msglevel." EQ "TRACE" or
          "&msglevel." EQ "DEBUG" or
          "&msglevel." EQ "WARN" or
          "&msglevel." EQ "ERROR") 
   %then %do;
      %put ERROR: (&MNAME), Type [&msglevel.] not supported.;
      %goto EXIT;
   %end;
   
   /*
      Default is to use agent location from SASEVCONFIGDIR pathing to put
      logs into agent logs directory
   */
   
   %let filrf=evmsgf;
   filename &filrf;
   %if "&floc" EQ "" %then %do;
      %if %symexist(SASEVCONFIGDIR) %then %do;   
         %let floc=%str(&SASEVCONFIGDIR/Events/sasev.events);
      %end;
      %else %do;
         %let floc=%str(sasev.events);
      %end;
      %if &debug GT 1 %then %put floc=[&floc];
   %end;
   %let rc=%sysfunc(filename(filrf,&floc));     /* zero is good here */
   %if "&rc" NE "0" %then %do;
      %put ERROR: (&MNAME), Failed to open filrf [&floc];
      %goto EXIT;
   %end;
   %let msgtext=%str(userid=&sysuserid  message=&msgtext);
   %let dt=%sysfunc(putn(%sysfunc(tzones2u(%sysfunc(datetime()))),B8601dz20.));
   
   %if &debug GT 2 %then %put &MNAME dt [&dt.];
   %let msg=%str(&dt|&msglevel|&src|&msgtext);

   %let fid=%sysfunc(fopen(&filrf,A));          /* zero is bad here */
   %if "&fid" EQ "0" %then %do;
      %put ******************************************************************;
      %put ERROR: (&MNAME) Failed append to [&floc] with return id [&fid] exiting;
      %put ******************************************************************;
      %goto EXIT;
   %end;
   %let rc1=%sysfunc(fput(&fid,&msg));
   %let rc2=%sysfunc(fwrite(&fid));
   %let rc3=%sysfunc(fclose(&fid));

   %if &debug GT 1 %then %put (&MNAME) FID=[&fid] RC1=[&rc1] RC2=[&rc2];;

   *%msg2stdout(msgtext=&msgtext,dest=&floc);
 
   %EXIT:
      %let rc3=%sysfunc(fclose(&fid));
%mend evevent;
