/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*---------------------------------------------------------------------------
  * NAME: %evodssetopts
  *                             
  * DESC: STP ods options.
  *          
  * UPDATED: 29Aug2013      rnb                              
  *-------------------------------------------------------------------------*/
%macro evodssetopt(evdest=,style=,path=,gpath=,file=,urlref=);

   %local MNAME style pathstmt;
   %global _ODSOPTIONS _RESULT _ODSDEST _ODSSTYLE _ODSSTYLESHEET; /* _gopt_device */
   %evsetdebug(SET,_debug=&evdebug);
   
   ods _all_ close;
   ods path (prepend) evconf.templat(read);

   %let MNAME=EVODSSETOPT;
   %let _gopt_device=PNG;
   %let evdest = %upcase(&evdest);
   
   %let evodsgrpopts=%str(width=1000px maxlegendarea=50);
   %if "&evodsgrpopts" NE "" %then %do;
      ods graphics on / &evodsgrpopts imagename="ACM";
   %end;

   %if &evdebug GT 1 %then %do;
      %evcomment((DEBUG) (&MNAME) EV Defaults, evodsdest=[&evodsdest.], evodsstyle=[&evodsstyle.],
      evodsopts=[&evodsopts.], evodsgrpopts=[&evodsgrpopts]);
      %evcomment((DEBUG) (&MNAME) _ODS Defaults, _odsdest=[&_odsdest.], _odsstyle=[&_odsstyle.],
      _odsstylesheet=[&_odsstylesheet], evdest=[&evdest.], style=[&style]);
      ods path show;
   %end;

   %if "&evdest" EQ "" %then %do;
      %if "&_odsdest" NE "" %then %let evdest=&_odsdest;
      %else %let evdest=&evodsdest;
   %end;
   %if "&style" EQ "" %then %do;
      %if "&_odsstyle" NE "" %then %let style=&_odsstyle;
      %else %let style=&evodsstyle;
   %end;
   %if "&path" NE "" and "&file" NE "" %then %do;
      %put ERROR: (&MNAME) Incompatible prompts path=[&path] file=[&file];
      %goto EXIT;
   %end;
   %if "&urlref" EQ "" %then %do;
      %let urlref=%str((URL=NONE));
   %end;    
   %let gpstmt=;
   %if "&gpath" NE "" %then %do;
      %let gpstmt=%str(gpath="&gpath.");
   %end;
   %else %if "&path" NE "" %then %do;
      %let gpstmt=%str(gpath="&path"&urlref.);
   %end;


   %if "&evdest" EQ "LISTING" %then %do;
      %let _odsdest=;
      %let _odsstyle=listing;
      %if "&style" NE "" %then %let _odsstyle=&style; 
      %let _odsstylesheet=; 
      %let _odsoptions=&evodsopts;
      %put %str(ODS LISTING;);
      %goto EXIT;
   %end;

   %let _odsdest = &evdest;
   %if "&_odsdest" EQ "HTML" or
       "&_odsdest" EQ "HTML5" or
       "&_odsdest" EQ "CHTML" or
       "&_odsdest" EQ "PHTML"
      %then %do;
         %if "&file" NE "" %then %do;
            %put ERROR: (&MNAME) Incompatible prompt file=[&file] with ODS Destination=[&evdest];
            %goto EXIT;
         %end;
         %if "&path" NE "" %then %let pathstmt=%str(path="&path."&urlref.);
         %else %let pathstmt=%str(path="%sysfunc(pathname(work))");
         %if "&style" EQ "" %then %let style=sasweb;
         %if "&_odsstyle" EQ "" %then %let _odsstyle=&style;
         %let _odsstylesheet=;
         %let _odsoptions= rs=none &evodsopts;
         %str(ods &evdest style=&_odsstyle &_odsoptions &pathstmt &gpstmt;);

      %end;
   %else %if %index(%upcase(&_odsdest),.SASREPORT) NE 0 %then %do; 
      %if "&path" NE "" %then %let pathstmt=%str(path="&path");
      %else %let pathstmt=%str(path="%sysfunc(pathname(work))");
      %let _odsstyle=normal;
      %if "&style" NE "" %then %let _odsstyle=&style;
      %let _odsstylesheet=; 
      %let _odsoptions=&evodsopts;
      %str(ods &evdest style=&_odsstyle &_odsoptions &pathstmt;);
   %end;
   %else %if "&_odsdest" EQ "RTF" %then %do; 
      %if "&path" NE "" %then %do;
         %put ERROR: (&MNAME) Incompatible prompt path=[&path] with ODS Destination=[&evdest];
         %goto EXIT;
      %end;  
      %if "&file" NE "" %then %let filestmt=%str(file="&file");
      %else %let filestmt=%str(file="%sysfunc(pathname(work))");
      %let _odsstyle=rtf;
      %if "&style" NE "" %then %let _odsstyle=&style; 
      %let _odsstylesheet=; 
      %let _odsoptions=bodytitle &evodsopts;
      %str(ods &evdest style=&_odsstyle &_odsoptions &filestmt;);      
   %end; 
   %else %if "&_odsdest" EQ "PDF" %then %do; 
      %if "&path" NE "" %then %do;
         %put ERROR: (&MNAME) Incompatible prompt path=[&path] with ODS Destination=[&evdest];
         %goto EXIT;
      %end;     
       %if "&file" NE "" %then %let filestmt=%str(file="&file");
      %else %let filestmt=%str(file="&sasevconfigdir./Reports/output"); 
      /*%else %let filestmt=%str(file="%sysfunc(pathname(work))");*/
      %let _odsstyle=printer;
      %if "&style" NE "" %then %let _odsstyle=&style; 
      %let _odsstylesheet=; 
      %let _odsoptions=bookmarkgen=no compress=9 startpage=no &evodsopts;
      %str(ods &evdest style=&_odsstyle &_odsoptions &filestmt;);
   %end;
   %else %do;
      %evcomment((&MNAME) Unknown [&_odsdest]);
      %let _odsdest=;
      %put %str(ODS LISTING;);
      %goto EXIT;
   %end;
   
%EXIT:
   %evcomment((&MNAME) Session Selections [&sysprocessmode], odsdest=[&_odsdest], odsstyle=[&_odsstyle], 
   odsstylesheet=[&_odsstylesheet], odsoptions=[&_odsoptions], odspath=[&path&urlref.], odsgpath=[&gpath&urlref.], odsgraphopts=[&evodsgrpopts]);

   options nodate nonumber missing='0' orientation=landscape;   
%mend evodssetopt; 