/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

%macro evrolldata(data=,               /* name of the input data set */
                  out=&data,           /* name of the output data set.  By default, this macro replaces the input data set */
                  var=datetime,        /* name of the variable that is the date or datetime field */
                  dateordt=DATETIME,   /* flag indicating whether the time variable is a DATE or DATETIME value */
                  numdays=,            /* the number of days that should be kept */
                  incMiss=NO,          /* should records with a missing value for the date field be included in the output? */
                  compress=YES,        /* set SAS data set option COMPRESS= */
                  dstype=EVDMRPT,      /* set SAS data set option TYPE= */
                  last=&today);        /* the last day that should be kept; defaults to today (for DATE values) or 11:59 PM today (for DATETIME values) */

 %local mname;
 %let mname=evrolldata;
 %evcomment((&MNAME) ...initializing);
 
 %if "&numdays" EQ "" %then %do;
    %everrmsg(&MNAME,msg=Missing or Invalid Value specified for NUMDAYS Parameter <&numdays.>.);
    %goto EXIT;
 %end;
 
 /* NEED TO DO SOME PARAMETER CHECKING */
 /* MISSING VALUES FOR NUMDAYS (and others?) SHOULD FORCE ABORT */
 /* If specified data set (DATA=) does NOT exist, ERROR */

 %local dstype_txt;

 %if "&dstype" ne "" %then
 %do; /* DSTYPE was specified */
   %let dstype_txt= %str(TYPE=&dstype);
 %end;/* DSTYPE was specified */
 
 %if "&dateordt" eq "DATE" %then 
 %do; /* dealing with DATE values */

    %let today = %sysfunc(today());
    %let units =DAYS;

 %end;/* dealing with DATE values */
 %else 
 %do; /* dealing with DATETIME values */

    data _null_;
     today = (cats("'",put(today(),date9.),":23:59'dt"));
     call symput("TODAY",today);
     put "INFO:" today=;

    run;
 
    %let units =DTDAYS;

 %end;/* dealing with DATETIME values */

 %let date=%sysfunc(intnx(&units,&last,%eval(%sysfunc(dequote(&numdays))*-1)));

 %if %sysfunc(exist(&data))%then
 %do; /* specified input data set exists */

   /* collect number of obs before roll-off */
   %local nobsBefore;
   %getnobs(data=&data,mvar=nobsBefore);


   data &out(compress=&compress &dstype_txt);
    set &data; 
    where (&var gt &date and &var le &last) 

   %if "&incMiss" eq "Y" or "&incMiss" eq "YES" %then
   %do; /* missing values for date var should be included */
       or (&var is missing);
   %end;/* missing values for date var should be included */

    ; /* DO NOT DELETE!  Ends the WHERE clause */
   run;

   /* collect number of obs after roll-off */
   %local nobsAfter;
   %getnobs(data=&out,mvar=nobsAfter);

   /* write roll-off metrics to table */
   %if %sysfunc(exist(WORK.__ROLLMETS)) %then
   %do; /* rolloff metric being collected */
     proc sql noprint;
      insert into work.__rollmets
       set data="&out",
            before= &nobsBefore,
            after=&nobsAfter,
            diff=&nobsBefore - &nobsAfter;
     quit;
   %end;/* rolloff metric being collected */

 %end;/* specified input data set exists */
 %else %put NOTE: *** Macro EVROLLDATA - Specified Input Dataset (&data) Does NOT Exist ***;
 
 %EXIT:

%mend evrolldata;