/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     evsetdebug.sas
   |
   | Product:  SAS Environment Manager
   | Language: SAS
   |
   | Purpose:  Enable or disable debugging messages depending on the
   |           value of evsetdebug and MODE paramter, IN or OUT. Different
   |           quantities of messages will be displayed dependent on
   |           the value of the evdebug global macro variable.
   | History:  Date    action
   |           062013  Initial Coding                              rnb
  +----------------------------------------------------------------+*/
%macro evsetdebug(mode,_debug=);
   %local mname;
   %global ev_note_state ev_src1_state ev_src2_state ev_mprn_state ev_stimer_state;
   %let mode = %qupcase(&mode);
   %let MNAME = evsetdebug;
   %if "&_debug" EQ "" %then %let _debug = &evdebug;
   
   %if NOT ("&mode" EQ "SET" or
       "&mode" EQ "RESET" or 
       "&mode" EQ "DISPLAY") %then %do;
       %put **********************************************************;
       %put (&MNAME) ERROR: Invalid option [&mode] (SET, RESET, DISPLAY);
       %put **********************************************************;
       %goto EXIT;
   %end;
    
   %*********************************************************;
   %* STORING STATE, SETTING DEBUG VALUES;
   %*********************************************************;
   %if "&mode" EQ "SET" %then %do;
      %let ev_note_state = %sysfunc(getoption(notes));
      %let ev_src1_state = %sysfunc(getoption(source));
      %let ev_srv2_state = %sysfunc(getoption(source2));
      %let ev_mprn_state = %sysfunc(getoption(mprint));
      %let ev_stimer_state = %sysfunc(getoption(stimer));
      %if "&_debug" EQ "0" %then 
         options nonotes nosource nosource2 nomprint nostimer;
      %else %if "&_debug" EQ "1" %then
         options notes fullstimer nosource nosource2 nomprint;
      %else %if "&_debug" EQ "2" %then
         options notes fullstimer nosource nosource2 mprint;
      %else %if "&_debug" EQ "3" %then
         options notes fullstimer source source2 mprint;
      %else %if "&_debug" EQ "4" %then
         options notes stimer source source2 mprint symbolgen mlogic fullstimer;         
      %else %do;
         %put ********************************************************;
         %put (&MNAME) ERROR: Invalid evdebug value [&_debug];
         %put ********************************************************;
      %end;
      %goto EXIT;
   %end;
   
   %*********************************************************;
   %* RETURNING TO SAVED STATE;
   %*********************************************************;
   %if "&mode" EQ "RESET" %then %do;
      options &ev_note_state &ev_src1_state &ev_src2_state &ev_mprn_state &ev_stimer_state nosymbolgen nomlogic;
      %goto EXIT;
   %end;
   
   %*********************************************************;
   %* DISPLAY;
   %*********************************************************;
   %if "&mode" EQ "DISPLAY" %then %do;
      %put ********************************************************;
      %put (&MNAME) DISPLAY DEBUG LEVEL SETTING;
      %put ********************************************************;
      %put evdebug = <&_debug>;
      %put notes   current = <%sysfunc(getoption(notes))>;
      %put stimer  stimer  = <%sysfunc(getoption(stimer))>;
      %put source  current = <%sysfunc(getoption(source))>;
      %put source2 current = <%sysfunc(getoption(source2))>;
      %put mprint  current = <%sysfunc(getoption(mprint))>;
      %put notes   stored = <&ev_note_state>;
      %put stimer  stored = <&ev_stimer_state>;
      %put source  stored = <&ev_src1_state>;
      %put source2 stored = <&ev_src2_state>;
      %put mprint  stored = <&ev_mprn_state>;   
      %goto EXIT;
   %end;
   
   %EXIT:
%mend evsetdebug;
