/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+------------------------------------------------------------------+
   | Copyright (c) 2013 by SAS Institute Inc., Cary, NC 27512-8000
   | Name:     evtimlog.sas
   | Product:  SAS Environment Manager
   | Language: SAS
   | Purpose:  Macro for printing elapsed time message in SAS log batch macros.
   | Parameters:
   |   Required parms:
   |           action    START means to init the elapsed timer.
   |                     STOP means to calculate the elapsed time and
   |                     print a message in the log.
   |           macro     evTIMLOG.
   |   Optional parms:
   |           reptname  Name of report macro.
   |
   | History:    date    action
   |             13Jul13 EV                                         rnb
   +---------------------------------------------------------------+ */
   
%macro evTIMLOG( action, macro, reptname );

    %local timelopt timechar datmchar mname;
    %global CP_NMSG evTIMLOG;
    %let mname=EVTIMLOG;
    %let action = %QUPCASE(&action);

    %if "&action" eq "START" %then %do;
       %let timelopt=%SYSFUNC(getoption(notes));
     
       data _null_;
          call symput('evTIMLOG',put(datetime(),25.2));
       run;
       options &timelopt;
    %end;

    %else %if "&action" eq "STOP" %then %do;
       %let timelopt=%SYSFUNC(getoption(notes));
       %let timechar=unknown;
       %let datmchar=unknown;
       data _null_;
          format d datetime19.;
          format t time.;
          d = datetime();
          t = d - input("&evTIMLOG",?? 25.2);
          if t eq . then do;
             put "WARNING: Unable to calculate elapsed time for "
                 "&macro &reptname..  "
                 "Perhaps evTIMLOG(STOP) invoked without evTIMLOG(START)?";
          end;
          else do;
             call symput( 'TIMECHAR', trim(left(put(t,time.))) );
             call symput( 'DATMCHAR', trim(left(put(d,datetime19.))) ) ;
          end;
       run;
       
       %evcomment((&mname) Elapsed time for (&macro),
          %UPCASE(&reptname) is &timechar at &datmchar);
       
       options &timelopt;
    %end;

    %else %do;
       %put ERROR: %NRBQUOTE(%)evTIMLOG(&action) is not (START) or (STOP);
    %end;

%mend evTIMLOG;
