/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
  | Name:     evwheval.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Evaluate where clause - both local and global.
  | History:  Date    action
  |           08Jun13 Initial Coding                              rnb
  | Future:
  | End
  +----------------------------------------------------------------+*/
  
%macro evwheval(where=,begin=,end=,type=DS,tzoneoff=);

   %local begindt enddt begindtn enddtn mname;
   %let mname=EVWHEVAL;
   %let begindt =;
   %let enddt=;

   %if "&tzoneoff." EQ "DATA" %then %do;
      %let tzsec = %str(0);
      %put **********************************************************************;
      %put EVWHEVAL CAUTION: Where subsetting may impact tzone filtering by observation;
      %put **********************************************************************;
   %end;
   %else %if "&tzoneoff." EQ "UTC" or
             "&tzoneoff." EQ "GMT" %then %let tzsec = %str(0);
   %else %do;
       %if "&tzoneoff." EQ "DATAMART"  %then %let tzsec = %str(&evdmtzoffset.);
                                       %else %let tzsec = %str(&tzoneoff.);
       %let test = %eval(&tzsec. + 0);
       %if %sysfunc(abs(&tzsec.)) GT 50400 
       %then %do;
          %put ***********************************************;
       	  %put ERROR: (&MNAME) Timezone offset seconds <&tzsec.> GT 1 day;
       	  %put ***********************************************;
          %goto EXIT;
       %end;
   %end;
   
   /*
   %if "&begin" NE "" %then %let begindt=%sysfunc(putn(%sysfunc(inputn(&begin,anydtdtm21)),DateTime16));
   %if "&end" NE "" %then %let enddt=%sysfunc(putn(%sysfunc(inputn(&end,anydtdtm21)),Datetime16));
   %put &MNAME Begindt <&begindt.> begin <&begin.> enddt <&enddt.> End <&end.>;
   */
   
   %if "&begin" NE "" %then %let begindt=%sysfunc(putn( %eval(%sysfunc(inputn(&begin,anydtdtm21))+&tzsec.),DateTime16));
   %if "&end" NE "" %then     %let enddt=%sysfunc(putn(%eval(%sysfunc(inputn(&end,anydtdtm21))-(&tzsec.)),Datetime16));
   
   %let type = %upcase(&type);
   
   %if &debug GT 1 %then %put DEBUG: (&MNAME) Begindt <&begindt.> begin <&begin.> enddt <&enddt.> End <&end.>;
   %if ("%quote(&begindt)" EQ "" or 
       "%quote(&enddt)" EQ "" or
       "%quote(&begin)" EQ "" or
       "%quote(&end)" EQ "") %then
      %do;
      %put *****************************************************;
      %put EVWHEVAL ERROR: Begin and end times must be specified;
      %put *****************************************************;
      %goto EXIT;
   %end;

   %if "&type" NE "DS" and "&type" NE "SQL" %then %do;
       %put ****************************************************;
       %put (&MNAME) ERROR: Type &type not supported;
       %put ****************************************************;
       %goto EXIT;
   %end;

   %if "&type" EQ "DS" %then %do;
      /* %if "%quote(&&&where)" NE "&" */
      %if "%nrbquote(&where)" NE ""
      %then %do;
         %let tmp = %qcmpres(%nrbquote(&where));
         %if &debug GT 1 %then %put DEBUG: (&MNAME) tmp <&tmp.>;
         %if %bquote(%qupcase(%qsubstr(&tmp,1,8)))=%bquote(SAME AND) 
            %then %do ;   /* where has SAME AND string */       
               %let scan3=%bquote(%scan(&where,3,%str( ))) ;
               %let index1=%index(&where,&scan3) ;
               %let qsubstr1=%quote(%substr(&where,&index1)) ;
               %let whlocal=%str(SAME AND (&qsubstr1) and) ;
               %let whlocal=%str(&whlocal datetime>="&&&begindt"dt %qleft(AND) datetime<="&&&enddt"dt);
               %let whlocal=%str(where %unquote(&whlocal) ;);
            %end;
            %else %do;
               %let whlocal=%str((%nrbquote(&where)) and) ;
               %let whlocal=%str(&whlocal datetime>="&&&begindt"dt %qleft(AND) datetime<="&&&enddt"dt);
               %let whlocal=%str(where %unquote(&whlocal) ;);
            %end;
      %end;
      %else %do;
         %let whlocal=%str(where SAME AND datetime>="&begindt"dt AND datetime<="&enddt"dt);
         %let whlocal=%str(%unquote(&whlocal));
      %end;
   %end;
   
   %else %do;           /* SQL FORMAT */
   %let begindtn=%sysfunc(inputn(&begindt,anydtdtm21));
   %let enddtn=%sysfunc(inputn(&enddt,anydtdtm21));
   %if &debug GT 1 %then %put DEBUG: (&MNAME) Begin <&begindt.> End <&end.>;
   %if "%nrbquote(&where)" NE ""
         %then %do;
            %let tmp = %qcmpres(%nrbquote(&where));
            %if &debug GT 1 %then %put DEBUG: (&MNAME) tmp <&tmp.>;
            %if %bquote(%qupcase(%qsubstr(&tmp,1,8)))=%bquote(SAME AND) 
               %then %do ;   /* where has SAME AND string */       
                  %let scan3=%bquote(%scan(&where,3,%str( ))) ;
                  %let index1=%index(&where,&scan3) ;
                  %let qsubstr1=%quote(%substr(&where,&index1)) ;
                  %let whlocal=%str(SAME AND (&qsubstr1) and) ;
                  %let whlocal=%str(&whlocal datetime>=&begindtn %qleft(AND) datetime<=&enddtn);
                  %let whlocal=%str(where %unquote(&whlocal) ;);
               %end;
               %else %do;
                  %let whlocal=%str((%nrbquote(&where)) and) ;
                  %let whlocal=%str(&whlocal datetime>=&begindtn %qleft(AND) datetime<=&enddtn);
                  %let whlocal=%str(where %unquote(&whlocal));
               %end;
         %end;
         %else %do;
            %let whlocal=%str(where datetime>=&begindtn %qleft(AND) datetime<=&enddtn);
            %let whlocal=%str(%unquote(&whlocal));
      %end;
   %end;
   %if &debug GT 1 %then %put DEBUG: (&MNAME) whlocal <&whlocal.>;
%EXIT:
   %evcomment((&MNAME) whlocal = %quote(&whlocal));
%mend evwheval;
