/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     get_batch_id.sas                                     |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Generates a BATCH_ID (batch identifier) based on a   |
   |           specified day; uses today if no date is specified    |
   |                                                                |
   | History:  Date    action                                       |
   |           17MAR17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   
%macro get_batch_id(date=,        /* Date to use for generating the batch identfier */
                    batch_id=,    /* Batch identifier */
                    increment=0); /* Number of days before/after DATE to use for generating the batch identfier */

  %emimacroinit();

    
  if date = . then date = today();
  increment=&increment;
    
  if "&batch_id" != "_DATE_" then batch_id="&batch_id";
  else
  do; /* calculate batch_id based on date */
   
    if increment lt 1 then increment=0;
    batch_id=putn(date+increment,"yymmdd6.");
      
  end;/* calculate batch_id based on date */
   
%mend get_batch_id;
