%macro get_input_stmt(resource_category=,
                      resourcetype=,
                      type=input,
                      version=&evdm_version);
/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/


/*+----------------------------------------------------------------+
  | Name:     get_input_stmt.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Creates INPUT and LENGTH statements for a resource
  |           
  |
  | Inputs    1. dm.evdm_versions
  |           2. resourceType
  |           
  |
  | History:  Date    action
  |           06Apr17 Initial Coding                          frf
  |           03MAY17 Rewrite to handle version checking      sasgzs
  |                   and use SQL to create macro variables.
  |
  | Future:
  | End
  +----------------------------------------------------------------+*/					  

 %symdel input_stmt length_stmt/nowarn;
 %global input_stmt length_stmt;

 %let EVDMERR=N;

 /* Check to see if there is file format info for specified criteria */
 %check_version(resource_category=&resource_category, resourcetype=&resourcetype, type=&type, version=&version);

 %if "&EVDMERR" eq "Y" %then %goto EXIT_ERR; 

 /*  Build INPUT_STMT and LENGTH_STMT for this resource.      */


 proc sql noprint;
  select var
   into :input_stmt separated by " "
    from evdm.evdm_versions
     where resource_category="&resource_category" and
           resource = "&resourcetype" and
           type = "&type" and
           evdm_version = "&version";

  select left(trim(var)) || " " || left(trim(lgth)) 
   into :length_stmt separated by " "
   from evdm.evdm_versions
    where resource_category="&resource_category" and
          resource = "&resourcetype" and
          type = "&type" and
          evdm_version = "&version";
 quit;

 %if &sqlobs lt 1 %then
 %do; /* no matching records found */
     %put %str(WARNING: No matching records for this criteria [&resource_category./&resourcetype./&type./&version].);
     %goto EXIT_ERR;
 %end;/* no matching records found */

 %return;

 %EXIT_ERR:
 %put WARNING: exiting without generating INPUT_STMT and LENGTH_STMT;
 %let EVDMERR=Y;

%mend get_input_stmt;
