/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     get_map_item.sas                                     |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Extracts the value of a single field from a          |
   |           complex/multi-value field (Golang Map object) and    |
   |           assigns it to a SAS macro variable.                  |
   |                                                                |
   | Note:     Item values must be Base64 encoded.                  |
   |                                                                |
   | History:  Date    action                                       |
   |           17MAR17 Initial Coding                        sasgzs |
   |           11MAY17 Revised to match new map pattern      sasgzs |
   |           01JUL17 Revised for Base64 encoded values     sasgzs |
   |           11AUG17 Added VARLENGTH parameter             sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   
 
%macro get_map_item(map=,                 /* SAS char variable containing the "map" */
                    key=,                 /* Name of the "key" to extract */
                    var=&key,             /* SAS variable to which to assign extracted key's value */
                    varlength=200,        /* Length of SAS variable to which to assign extracted key's value */
                    kv_delim=%str(:),     /* delimiter character used between key and value */
                    item_delim=%str(,));  /* delimiter character used between map items */

 %global __gmi_index;

 %if %symexist(__GMI_INDEX) %then
 %do; /* increment index */
    %let __gmi_index=%eval(&__gmi_index+1);
 %end;/* increment index */
 %else %let __gmi_index=1;

 %let regex_var=regex&__gmi_index;
 %let found_var=found&__gmi_index;
 
 retain &regex_var _gmi_dequote_re;

 if _n_ eq 1 then
 do; /* initialize regular expression patterns */

     _gmi_dequote_re=prxparse('/^"(.*)"\s*/o');
     
     _gmi_pattern=catt("/",                             /* regex pattern - start */                    
                      '(',                              /* KEY NAME capture group - start */
                      "&key",                           /* KEY NAME */
                      ')',                              /* KEY NAME capture group - end */
                      "&kv_delim",                      /* key/value delimiter */
                      "(",                              /* KEY VALUE capture group - start */
                      "(?:[A-Za-z0-9+\/])*(?:={0,2})",  /* KEY VALUE */
                      ')',                              /* KEY VALUE capture group - end */
                      "&item_delim.?",                  /* item delimiter; may NOT be there on last kvp */
                      "/oi");                           /* regex pattern - end + flags */
                     
    &regex_var=prxparse(_gmi_pattern);                     
    
 end;/* initialize regular expression patterns */

 length &var $&varlength;
 
 &found_var = prxmatch(&regex_var,&map); 
 
 if &found_var then 
 do; /* match made! */ 

    &var=input(prxposn(&regex_var,2,&map),$base64x640.);        
    if prxmatch(_gmi_dequote_re,&var) then &var=prxposn(_gmi_dequote_re,1,&var);
    
 end;/* match made! */
 
 drop &regex_var &found_var _gmi_pattern _gmi_dequote_re;

%mend get_map_item;
