/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     SASMacros/get_tsv_file_list.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Used by rolloff.sas to find TSVs to use in the load process 
  |
  |
  |
  | History:  Date    action
  |           31AUG17 Initial Coding                           sasgzs
  |
  | Future:
  | End
  +----------------------------------------------------------------+*/

%macro get_tsv_file_list(data_dir=, 
                         out=work.tsvfiles,                        
                         start_date=0,
                         end_date=%sysfunc(today()),
                         namematchrx=
                         );

 %if %sysfunc(fileexist(&data_dir)) eq 0 %then 
 %do; /* confirm specified data directory exists */

    %put %str(NOTE: The specified data directory [&data_dir] does not exist; skipping this directory); 
    %let _nodata=Y;
    %return; 

 %end;/* confirm specified data directory exists */
 

 libname rt "&data_dir";

 %findfiles(dir=&data_dir, 
            outds=work._tsvfiles, 
            namematchrx=&namematchrx);

 proc sort data=work._tsvfiles out=work.found(rename=(logfile=tsv_file_name));
  by logfile;
 run;


 %if %sysfunc(exist(RT.INVENTORY)) eq 0 %then
 %do; /* initialize the table if it does not exist */
 
    data rt.inventory;
      length tsv_file_name $200 file_ext $3 file_date 8 finalized $1 last_moddate 8 last_rec 8;
      format last_moddate datetime. file_date yymmddn8.;
     stop;
    run;
    
 %end;/* initialize the table if it does not exist */

 lock rt.inventory;

 data &out;
  merge rt.inventory(in=known) work.found(in=found);
  by tsv_file_name;

  if found and known then
  do; /* file was previously found */
      
     /* don't update files that aven't */
     /* been modified since their */
     /* info in RT.INVENTORY was  */
     /*  last updated.            */
     if last_moddate eq modfdt then
     do; /* inventory table is up-to-date */

        update_action="IGNORE";
        next_rec=.;

     end;/* inventory table is up-to-date */
     else
     do; /* inventory table needs to be updated */
 
        update_action="UPDATE";
        next_rec=max(1,last_rec);

     end;/* inventory table needs to be updated */
    
  end;/* file was previously found */
  else if found and not known then do; update_action="ADD"; next_rec=1; end;
  else if known and not found then delete; /* ignore 'obsolete' files */


*  if file_date eq . or file_ext eq "" then
  do; /* extract file_date and file_ext */    

      re=prxparse("/(((\d{4})(\d{2})(\d{2}))?(?:(\w+)?)-(\S+)(?:\.(tsv)))(?:\.(\w+))?/");
      match=prxmatch(re,tsv_file_name);

      file_name=prxposn(re,1,tsv_file_name);
      file_date=input(prxposn(re,2,tsv_file_name),yymmdd8.);
          /*YEAR: 3 */
          /*MONTH: 4 */
          /*DAY: 5 */
      file_type=prxposn(re,6,tsv_file_name);
      vstring  =prxposn(re,7,tsv_file_name);
      file_ext =prxposn(re,8,tsv_file_name); 
      file_zip =prxposn(re,9,tsv_file_name);

     drop re match vstring;

*  end;/* extract file_date and file_ext */    

  if file_date ge &start_date and file_date le &end_date;


  filename=catt(directory,'/',tsv_file_name);
  
 run;

 
%mend get_tsv_file_list;

