/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     get_tsv_file_version.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  extract version number from TSV input file
  |           
  |
  | Inputs    output table from FINDFILES	
  |           
  |
  | History:  Date    action
  |           26Apr17 Initial Coding                              frf
  |			  03May17 Create permanent evdm.metricproperties      frf
  |                   and do not create has_counters. That will   frf
  |                   be created in calc_rates.
  | Future:
  | End
  +----------------------------------------------------------------+*/

%macro get_tsv_file_version(tsv_input=,);
/*                                          */
/* Extract version number from filename.    */
/* For example,                             */
/* TSV_FILE_VERSION=1.3.8-SNAPSHOT          */
/*                                          */
/* also extract the date on the TSV file.   */
/* For example, 20170401                    */
/*                                          */

%global tsv_file_version tsv_file_date;
%local file file_length tsv_start tsv_end;

%let file=%scan(&tsv_input,-1,/);
%let tsv_file_date=%substr(&file,1,8);
%let file_length=%length(&tsv_input);
%let tsv_start=%eval(%index(&file,-) + 1);
%let tsv_end=%eval(%index(&file,.tsv) - 1);

%let tsv_file_version=%cmpres(%substr(&file,&tsv_start,%eval(&tsv_end - &tsv_start + 1)));
%let header_path=&evdmpath./headers-&tsv_file_version..tsv;
%put tsv_file_version=&tsv_file_version header_path=&header_path;

/*                                               */
/* Need to parse header file for this version    */
/* and create table HAS_COUNTERS. Older versions */
/* (1.3.5 and 1.3.6 have different formats in the*/
/* header.                                       */
/*                                               */

/*
%let header_file=%qcmpres(&header_path);
filename tsvhdr "&header_path";		

data hdr;infile tsvhdr missover length=lv;
	length resourcetype $32. tsv_file_version $20.;

	input @1 line $varying4096. lv;
		tsv_file_version=compress(symget('tsv_file_version'));	
		 	
			num_vars=count(line,'(');
			tab='09'x;
			first_blank=index(line,tab);
			slash=index(line,'/');
			
			 if index(tsv_file_version,'1.3.5-SNAPSHOT') ne 0 or
			    index(tsv_file_version,'1.3.6-SNAPSHOT') ne 0 then do;
			  if substr(line,1,6)='metric' then resourcetype=substr(line,slash+1,first_blank-slash-1);
			 	else resourcetype=substr(line,1,first_blank-1);
			 end;
			 
			 else do;		      	    
			  resourcetype=substr(line,slash+1,first_blank-slash-1);
			 end;
			
			line = left(substr(line,first_blank,length(line)-first_blank+1));
			
		put 'In get_tsv_file_version resourcetype=' resourcetype ' resourcetype=' resourcetype $hex32.
		' version=' tsv_file_version;
run;
proc sort data=hdr;by resourcetype;
run;
data columns  (keep=var resource:)
	 metricproperties(keep=resource:  tsv_file_version
					  metric: detail: unit);
	 set hdr;
	 length metrictype unit $7. metricname $22. detailLevel 8.;
	 drop l_paren line tab first_blank i num_vars;
	length raw_var var $64. ;	
		do i=1 to num_vars;			
			raw_var = left(scan(line,i,')'));
			L_paren = index(raw_var,'(');
			var = substr(raw_var,2,l_paren-2);
			
				if index(raw_var,',') ne 0 then do;				 
					detailLevel=scan(raw_var,2,',');
					unit=scan(raw_var,3,',');
					metrictype=scan(raw_var,4,',');
					metricname=var;					
					output metricproperties;
				end;
			output columns;
		end;		
run;
proc append base=evdm.metricproperties data=metricproperties;
run;
proc sort data=evdm.metricproperties nodupkeys;
	by tsv_file_version resourcetype metricname;
run;

proc sort 
	data=metricproperties(where=(lowcase(metrictype)='counter' and lowcase(unit) ne 'none'
							and resource_type= and tsv_file_version=));
    out=Has_counters nodupkeys;
	by resourcetype metricname;
run;
*/
%mend get_tsv_file_version;






