/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     getkeyprop.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Creates macro variables from an argument or env variable 
  |
  |
  | Inputs    Env var which will become a macro variable
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
/*
	mvar=Name of key property
	envvar=Env Var Name used to set key property value (if different)
	default=Default value for key property if none is found
*/

%macro getkeyprop(mvar=,          
                  envvar=&mvar,
                  default=);      

 /* If a env var name has NOT been provided,  */
 /* assume it should match key property name. */

 %if "&envvar" eq "" %then %let envvar=&mvar;

 /* If a SAS Macro var with the right name    */
 /* exists, do nothing; i.e. use its value to */
 /* set key property.   Otherwise, look for   */
 /* an environment variable.                  */

 %if %symexist(&mvar) eq 0 %then %do; /* macro var does not exist */

        %if %sysfunc(envlen(&envvar)) gt 0 %then %do; /* specified environment variable exists */

          %global &mvar;

          %let &mvar=%sysget(&envvar);
          %put NOTE: Macro variable [&mvar] was set from environment variable [&envvar];
          %put NOTE: [&mvar] equals [&&&mvar];

        %end;/* specified environment variable exists */

        %else %if "&default" ne "" %then %do; /* a default value was provided */

           %global &mvar;

           %let &mvar=&default;
           %put NOTE: Macro variable [&mvar] was set from specified default [&&&mvar];

        %end;/* a default value was provided */

        %else %do; /* no value for key property can be found */

           %global &mvar;
           %put NOTE: Macro variable [&mvar] defined to global symbol table;

        %end;/* no value for key property can be found */
 %end;/* macro var does not exist */
%mend getkeyprop;
