/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     idx_exportData.sas                                   |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Misc utility                                         |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAy17 Initial Coding                        frefor |
   |                                                                |
   |                                                                |
   +----------------------------------------------------------------+*/

%macro idx_exportData(caslib=, indexname=, batch_id=, out_caslib=, out_table=);

    %if "&batch_id"  ne "None" %then
    %do; /* batch-id provided */
   
        query_json = '{"fieldmatch" : {"field": "BATCHID", "terms" : ["'||"%trim(&batch_id)"||'"]}}';
        
        action search.searchIndex  result=results status=s;
        param index={'caslib'="&caslib" 'name'="&indexname"}
              casout={'caslib'="&out_caslib" 'name'="&out_table" 'replace'="True"}
              query=query_json;

        %check_results(status=s, results=results, message='Exporting data from the index');
        
        if rc eq 0 then
        do; /* succesful extract of data */

            action table.recordcount  result=results status=s;
            param table={'caslib'="&out_caslib" 'name'="&out_table"};
            
            cinfo = findTable(results); 
 
            do col over cInfo;  
               rowcount=col.N;
            end; 
            /*logger.debug('rowcount:' + str(rowcount)) */

            if rowcount > 0 then
            do; /* exported table contains rows */
           
                %saveTable(caslib=&out_caslib, table=&out_table);
                
                if rc eq 0 then
                do; /* table saved */
                    %dropTable(caslib=&out_caslib, table=&out_table);
                end;/* table saved */
               
            end;/* exported table contains rows */
            else
            do; /* no rows in exported table */
                /* logger.info('Exported table contained no data') */
                rc = 1;
            end;/* no rows in exported table */
            
        end;/* succesful extract of data */
       
        if rc eq 0 then 
        do;
            /* logger.info('The data export process was completed successfully'); */
        end;    
    %end;/* batch-id provided */            
    %else
    %do; /* missing batch-id */
   
        /*         logger.error('A batch_id value is required; no batch_id was provided.') */
              
       /* MISSING REQUIRED INFORMATION */
       /*    BATCH_ID                  */
      
       rc = 2;
    %end;/* missing batch-id */
            
%mend idx_exportData;
