/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     initIndex.sas                                        |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Builds/Initializes CAS Search Index                  |
   |                                                                |
   | History:  Date    action                                       |
   |           17MAR17 Initial Coding                        sasgzs |
   |           16AUG17 Drop the CAS Search table before      sasgzs |
   |                   initializing it.                             |
   |                                                                |
   +----------------------------------------------------------------+*/
   
%macro initIndex(caslib=,        /* CASLIB of target CAS Search Index */
                 indexname=,     /* name of target CAS Search Index */
                 schemafile=);   /* name of file containing CAS Search Index schema */

  %emimacroinit();

  
  /* drop any existing list of unique SOURCE values */
  /* associated with this target CAS Search Index.  */
  %droptable(caslib=&caslib,
             table=&indexname._SOURCES);
  run;


  /* drop any existing instance of the index.       */
  %droptable(caslib=&caslib,
             table=&indexname);
  run;


  /* (re-)initialized the target CAS Search Index.  */
  schemafile=readpath("&schemafile");
  action buildindex status=s ;
  param schema=schemafile
        index={caslib="&caslib" name="&indexname", promote=true};
  run;
  
%mend initIndex;
