/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/
 
/*---------------------------------------------------------------------------
  * NAME: jobheader.sas
  *
  * DESC: Macro to send session information to SAS log.
  *
  * UPDATED: 20Nov2013       rnb
  * UPDATED: 27Nov2013       gzs
  *          30Nov2013       rnb   
  *          02DEC2013       gzs   
  *-------------------------------------------------------------------------*/

%macro jobheader(jobname=, jobid=, stepname=, stepdesc=);

  %if "&jobname" eq "" %then %do;          /* no jobname provided info */
    %put NOTE: SAS Macro JOBHEADER -- No JOBNAME provided.;
    %put The value of the automatic macro variable SYSPROCESSNAME will be used.;
    %let jobname2 = &sysprocessname.;
  %end;
  %else %do;                               /* use provided info */
    %let jobname2 = &jobname.;
  %end;
  %if "&jobid" eq "" %then %let jobid=&RUNID;
  
  %put JOB HEADER BEGIN (ver=1.1) *********************************************;
  %put JOB HEADER jobname=&jobname2;
  %put JOB HEADER runid=&RUNID.;

  %if "&stepname" ne "" %then %do;        /* step info */
  
     %put JOB HEADER stepname=&stepname;
     %put JOB HEADER stepdesc=&stepdesc;

  %end;
  
  %else %do;                              /* job info */

     %put JOB HEADER stepname=BEGIN;
     %put JOB HEADER host=&SYSHOSTNAME.;
     %put JOB HEADER os=&SYSSCP.;
     %put JOB HEADER user=&SYSUSERID.;
     %put JOB HEADER timezone=&SYSTIMEZONEOFFSET.;
     %put JOB HEADER ver=&SYSVLONG.;
     %put JOB HEADER parm=&SYSPARM.;
     %put JOB HEADER sysjobid=&SYSJOBID.;
     %put JOB HEADER sysprocessname=&SYSPROCESSNAME.;
     %put JOB HEADER memsize=%sysfunc(getoption(MEMSIZE));
     %put JOB HEADER sumsize=%sysfunc(getoption(SUMSIZE));
     %put JOB HEADER sortsize=%sysfunc(getoption(SORTSIZE));     

  %end;/* job info */  
  
  %if %symexist(evbegin) %then %put JOB HEADER evbegin=&evbegin;
  %if %symexist(evend) %then %put JOB HEADER evend=&evend;
  %put JOB HEADER END *********************************************************;

%mend jobheader;

