/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     json2csv.sas                                         |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Misc utility                                         |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAy17 Initial Coding                        frefor |
   |                                                                |
   |                                                                |
   +----------------------------------------------------------------+*/

%macro json2csv(jsonfile=,                 /* json file to read */
                mapfile=,                  /* json libname map file */
                outlib=IN2,                /* LIBREF used for JSON libname */
                table=VIYALOG,             /* table name of log message table */
                csvfile=,                  /* full path to CSV file to create */
                delimiter="09"x,           /* field delimiter in output CSV file */
                varlist=_all_,             /* list of variables to write to CSV */
                renamelist=NONE,           /* list of variables to rename; in form: oldname=newname */
                dsoptions=%str(obs=MAX));  /* additional data set options */

  %if %upcase("&varlist") eq "_ALL_" %then
  %do; /* want to output all JSON fields to CSV */
     proc sql noprint;
      select distinct name
       into :varlist separated by ' '
        from sashelp.vcolumn
         where libname eq "&outlib" and 
               memname="&table";
     quit;
  %end;/* want to output all JSON fields to CSV */

  %if %upcase("&renamelist") ne "NONE" %then
  %do;/* need to rename some fields */
     %let dsoptions=%str(&dsoptions rename=(&renamelist));
  %end;/* need to rename some fields */

 
  filename test "&csvfile";

  libname in2 sasejson "&jsonfile" map="&mapfile";

  data _null_;
   length varlist $200 varname $ 32;
   set &outlib..&table.(&dsoptions);

   file test delimiter=&delimiter;

   if _n_ eq 1 then
   do; /* print headers */
      varlist="&varlist";

      do until(varname eq "");
         vcount+1;
         varname=scan(varlist,vcount,' ');

         if varname ne "" then 
         do; /* have a variable name */
            varname_quoted='"' ||trim(varname)||'"' ;
            put varname_quoted @;
         end;/* have a variable name */
	     else put;
	     
	     *putlog vcount= varname=;
      end; /* do-until */

   end;/* print headers */
   put &varlist;
  run;

%mend json2csv;
