/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

/*+----------------------------------------------------------------+
  | Name:     loadprops
  | Product:  SAS Environment Manager
  |
  | Language: SAS
  | Purpose:
  | History:  Date    action
  |           08Jun13 Initial Coding                              gs
  | Future:
  | End
  +----------------------------------------------------------------+*/

%macro loadprops(propfile='./evsasvars.properties', 
                 prefix=,
                 propname=_ALL_,
                 scope=G,
                 debug=N);

/* property file lines limited to 2000 chars        */
/* ignores blank lines, lines starting with "#"     */
/* specified property not found? EXIT               */
/* periods removed from macro variable names        */
/* invalid macro variable name? ABORT               */
/* non-comment/non-blank line missing an "="? ABORT */ 

   %local MNAME propfilename;
   %let MNAME=loadprops;
   %let debug=%upcase(&debug);
   
   %if not %sysfunc(fileexist(&propfile)) %then %do;
      %put *******************************************************;
      %put ERROR: (&MNAME) File [&propfile] does not exist. Halting;
      %put *******************************************************;
      %goto EXIT;
   %end;
   /*%let propfilename=%qscan(&propfile.,-1,/\''"");*/
   %evcomment((&MNAME) Loading properties [&propname]);
   %put INFO: (&MNAME) Properties file [&propfile];

   %if "&prefix" ne "" and "&propname" eq "_ALL_" %then %let propname=;  /* specifying a PREFIX overrides PROPNAME eq _ALL_ */
   %else %if "&prefix" ne "" and "&propname" ne "" %then %let prefix=;   /* specifying a PROPNAME overrides PREFIX */

   %if "&scope" eq "" %then %let scope=G;  /* default to GLOBAL symbol table */
   
   data _null_;
     length line $2000;

     infile &propfile lrecl=2000 pad missover;
     input line &;

     if substr(line,1,1) ne "#" and line ne "";
  
     fsteqloc = index(line,'=');

     if fsteqloc then 
     do; /*found an = */

        mvarname=compress(scan(line,1,'='),".");
        
        select;
         when (upcase(mvarname) eq: upcase("&prefix"));   /* specified a prefix */
         when (upcase(mvarname) eq upcase("&propname"));  /* specified a particular property */
         when (upcase("&propname") eq "_ALL_");           /* requested ALL properties found */
         otherwise delete;                                /* these are not the properties you are looking for */
        end; /* select */

        mvalue=substr(line,fsteqloc+1,length(line));

     end;/*found an = */
     else
     do; /* no = found */

        putlog "&MNAME " &propfile "missing = in name value pairs";
        abort;

     end;/* no = found */
 
     %if "&DEBUG" eq "Y" or &evdebug GT 1 %then %do; /* write values to the log */
        putlog "&MNAME " mvarname= mvalue=;
     %end;

     if notname(trim(mvarname)) then
     do; /* specified name includes invalid characters */

        putlog "ERROR: (&MNAME) Invalid Macro Variable Name found in property file:" mvarname;
        abort;

     end;/* specified name includes invalid characters */

     call symputx(mvarname,trim(mvalue),"&scope");
              
  run;
 
  %EXIT:

%mend loadprops;