/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

%macro lockds(lib=,
              table=,
              action=,
              limit=6,
              abortOnErr=N);

 /* %global evdebug; */
%if "&evdebug" ge "1" %then %put NOTE: *** Macro LOCKDS: Called to &ACTION table (&lib..&table)***;

 /* %global evdmerr; */
 %local exit tries wait;

 %let wait=10;

 %let tries=0;
 %let exit=0;

 %if NOT %sysfunc(anydigit(&limit)) %then
 %do; /* invalid LIMIT value */

    %put ERROR: *** Macro LOCKDS: An invalid value has been specified for the maximum number of attempts (Max Number of Attempts=&limit). ***;
    %let evdmerr=Y;
    %return;

 %end;/* invalid WAIT and/or LIMIT value(s) */

 %if %eval(&limit*&wait) lt 1 or %eval(&limit*&wait) gt 300 %then
 %do; /* invalid WAIT and/or LIMIT value(s) */

    %put ERROR: *** Macro LOCKDS: An invalid time limit has been specified must be between 0 and 300 seconds (Max Attempts=&limit %str(;) Wait=&wait seconds) ***;
    %let evdmerr=Y;
    %return;

 %end;/* invalid WAIT and/or LIMIT value(s) */

 %if NOT %sysfunc(exist(&lib..&table)) %then
 %do; /* invalid table specified */

       %put ERROR: *** Macro LOCKDS: Specified table (&lib..&table) does not exist ***;
       %let evdmerr=Y;
       %return;

 %end;/* invalid table specified */

 %if "&evdmerr" ne "N" %then
 %do; /* error flag already set */

    %return; /* exit immediately if error flag already set */

 %end;/* error flag already set */

 %if "&action"  eq "CLEAR" %then
 %do; /* clear a data set lock */

    lock &lib..&table clear nomsg;

 %end;/* clear a data set lock */
 %else %if "&action" eq "LOCK" %then
 %do; /* lock the data set */

     %do %until(&exit);

        lock &lib..&table;

        %if &syslckrc le 0 %then
        %do; /* lock obtained! */

             %let exit=1;

        %end;/* lock obtained! */
        %else %if %eval(&tries) ge &limit %then
        %do; /* too many attempts w/o success */

             %let exit=2;

        %end;/* too many attempts w/o success */
        %else
        %do; /* wait before trying again */

            %let tries=%eval(&tries+1);
            %let sleeprc=%sysfunc(sleep(&wait,1));

        %end;/* wait before trying again */

     %end; /* %do-%until */

     %if %eval(&syslckrc) le 0 %then
     %do; /* lock successful*/

          %put NOTE: *** Macro LOCKDS: Lock on &lib..&table has been obtained. ***;

     %end;/* lock successful*/
     %else
     %do; /* lock timed out */

         %put ERROR: *** Macro LOCKDS: Lock on &lib..&table could NOT be obtained within the specified time limit. Error code=&syslckrc ***;

         %let evdmerr=Y;

         %if "&abortOnErr" eq "Y" %then %abort abend 156;

     %end;/* lock timed out */

 %end;/* lock the data set */

 %mend lockds;
