/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     logs_etl.sas                                         |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose: Updates a CAS Search Index with the (partial/full)    |
   |          contents of a TSV file after performing some remapping|
   |          of variable names and extracting sub-fields from      |
   |          complex/multi-value fields (e.g. PROPERTIES); saves   |
   |          the index after updating it.                          |
   |                                                                |
   | History:  Date    action                                       |
   |           31MAR17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   

%macro logs_etl(inputtsv=,               /* file to read */
                firstobs=,               /* first record in input file to read */
                lastrecread=,            /* name of macro var to hold last record read info */
                delimiter="09"x,         /* field delimiter in file */
                resource_category=log,   /* Resource category (always 'log') */
                resourcetype=log,        /* Resource type (always 'log') */
                update_cas=Y,            /* Y|N flag to indicate whether CAS SEARCH INDEX should be updated */
                caslib=,                 /* CASLIB of target CAS Search Index */
                casmemname=);            /* name of target CAS Search Index */


  %emimacroinit();

  %if "&resource_category" eq "" %then %let resource_category=&resourcetype;;

  %tsv2sasds(file=&inputtsv, 
             resource_category=&resource_category, resourcetype=&resourcetype, type=input, 
             out=WORK.VIYALOGS, dstype=view, 
             firstobs=&firstobs, lastrecread=atobs, delimiter=&delimiter);
 
  %macro rename(from=,to=);
   rename &from.=&to.;
   keep &from;
  %mend rename;
 
 /* map data set vars to schema input fields */
 /* need to make this version-specific/sensitive? */

 data work.remapped/view=work.remapped;
  length batchid $10;
  set work.viyalogs;
 
  %rename(from=sasevent_id,to=id);
  %get_map_item(map=sasevent_headers,key=sas-deployment-id,var=deploymentid,varlength=25);
  keep deploymentid;

  %get_map_item(map=sasevent_headers,key=__tenant,var=tenantid,varlength=25);
  keep tenantid;

  payload_level=upcase(payload_level);
  %rename(from=Payload_Level,to=level);

  %rename(from=Payload_Source,to=source);
  %rename(from=Payload_Message,to=message);

  batchid=putn(datepart(datetime),'yymmdd6.');
  keep batchid datetime;

  %get_map_item(map=payload_properties,key=hostname,var=machine, varlength=256);
  %get_map_item(map=payload_properties,key=consulnodename,var=consulnodename, varlength=256);
  keep machine consulnodename;

 run;

 %if "&update_cas" eq "Y" %then
 %do; /* update  CAS Search Index */

    %get_cas_session();

	%ev_status(action=casLogconnect);

    proc casutil outcaslib=&caslib ;
     load data=work.remapped casout="_TEMP"  replace;
     run;
    quit;

	%ev_status(action=casLogLoad);

    %let indexname=&casmemname;

    proc cas;		  
     %appendIndex(caslib=&caslib, 
                  indexname=&indexname, 
                  type=TABLE, 
                  load_lib=&caslib, 
                  load_table=_TEMP);
     run;
    quit;

    /* update "master" list of possible sources */
    %ck4newvals(masterlib=&caslib, mastertable=%str(&indexname)_sources, data=_TEMP);
 
    proc cas;
    /* ************************************ **
     ** COMMENTING OUT SAVEINDEX FOR NOW;   **
     ** NEED TO DECIDE IF DOING IT IS       **
     ** WORTH THE ADDITIONAL SPACE.         **

     %saveIndex(caslib=&caslib, 
                indexname=&indexname, 
                index_attr_suffix=%str(_INDEX_ATTR));
     run;
     **                                     **
     ************************************** **/
     %droptable(caslib=&caslib, table=_TEMP);
     run;

    quit;
 
 %end; /* update  CAS Search Index */
 
  %ev_status(action=casLogSearchLoad);
 
%mend logs_etl; 
