/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     makeshiftfmt.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Creates SHIFT formats 
  |
  |
  | Inputs    evdm.shiftmap
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro makeshiftfmt(data=shiftmap,      /* name of the input data set */
                    fmtname=SHIFT,      /* name of the format to be created based on ID var */
                    fmtname2=SHIFTTXT,  /* name of the format to be created based on DESC var */
                    fmtname3=SHIFT2TXT, /* name of the format maping ID var to DESC var */
                    fmtname4=SHIFTXT2ID,/* name of the format mnapping DESC var to ID var */
                    lib=WORK);          /* format library in which to create the formats */

 /* TO DO: Allow user to specify variables to use for start/stop/id/desc? */

 data formatin;
   retain eexcl 'Y';
   retain fmtname  "&fmtname";
   retain fmtname2 "&fmtname2";
   retain fmttype  "N";

   set &data(rename=(start=oStart)) end=lastrec;

   start=dow+(ostart/100000);
   end  =dow+(stop/  100000);


   label=id;

   output;

   if lastrec then
   do; /* output an OTHER record */

     hlo  ="O";
     id="X";
     label="X";
     desc="UNDEFINED";
     output;

   end; /* output an OTHER record */
 run;

 proc format library=&lib cntlin=formatin;
 run;

 /* TO DO: Add conditional logic to only create the additional formats if fmtname2 is provided */

 /* create 2nd format that outputs text shift name */
 proc format library=&lib cntlin=formatin(drop=label fmtname
                                          rename=(fmtname2=fmtname
                                                  desc=label));
 run;

 proc sql;
 create view formatin2 as
  select distinct id as start,
                   desc as label,
                   "$&fmtname3" as fmtname,
                   "C" as fmttype
    from work.formatin
   union all
   select distinct desc as start,
                   id as label,
                   "$&fmtname4" as fmtname,
                   "C" as fmttype
    from work.formatin;
  quit;

 proc format library=&lib cntlin=formatin2;
 run;


%mend makeshiftfmt;
