/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     metric_load_output                                   |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose: Updates a CAS table with the (partial/full) contents  |
   |          of a metrics "output" TSV file.                       |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAY17 Initial Coding                        sasgzs |
   |           19Jul17 Add call to FORMAT_VARS_FOR_CAS to format    |
   |                   datetime to datetime22.                      |
   |                                                                |
   +----------------------------------------------------------------+*/
   

%macro metric_load_output(inputtsv=,               /* file to read */
                          firstobs=,               /* first record in input file to read */
                          lastrecread=,            /* name of macro var to hold last record read info */
                          delimiter="09"x,         /* field delimiter in file */
                          resource_category=log,   /* Resource category */
                          resourcetype=log,        /* Resource type  */
                          update_cas=Y,            /* Y|N flag to indicate whether CAS table should be updated */
                          caslib=,                 /* CASLIB of target CAS table */
                          casmemname=);            /* name of target CAS table */


  %emimacroinit();

  %let firstobs=%sysfunc(max(&firstobs,2));  /*output TSV files have a header row to skip */

  %if "&casmemname" eq "" %then %let casmemname=&resourcetype;;
  
  %tsv2sasds(file=&inputtsv, 
             resource_category=&resource_category, resourcetype=&resourcetype, type=output, 
             out=work.metrics, dstype=table,
             firstobs=&firstobs, lastrecread=atobs, delimiter=&delimiter);
             
  %if "&update_cas" eq "Y" %then
  %do; /* update  CAS Table */
 
     /*                                                       */
     /* Format DATETIME and SHIFT before loading into CAS.    */
     /*                                                       */
    
    %format_vars_for_cas(table=metrics,var=datetime,fmt=datetime22.);
    %format_vars_for_cas(table=metrics,var=SHIFT,fmt=shifttxt.);
    
     %get_cas_session();
     
     proc cas;
      %tableexists(caslib=&caslib, table=&resourcetype);
      run;
      /* If exists: do what? */
      %appendSASTable(out_caslib=&caslib, out_table=&casmemname, data=work.metrics, mode=append);
      run;
     quit;
	  
  %end; /* update  CAS Table */
 
%mend metric_load_output; 
