/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     notification_etl.sas                                 |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose: Reads notification TSVs and appends to CAS            |
   |                                                                |
   | History:  Date    action                                       |
   |           25Mar17 Initial Coding                        frefor |
   |                                                                |
   +----------------------------------------------------------------+*/
   
  /* 
filename evmacs "/opt/sas/viya/home/lib/evmsvrops/SASMacros";
options insert=sasautos=(evmacs);   
*/
%let evdebug=1;
%let evdmpath=/opt/sas/viya/config/var/lib/evmsvrops/evdm;
libname evdm "&evdmpath";
options mprint;
%macro notification_etl(inputtsv=,               /* file to read */
                firstobs=,               /* first record in input file to read */
                lastrecread=,            /* name of macro var to hold last record read info */
                delimiter="09"x,         /* field delimiter in file */
                resource_category=notification,   /* Resource category (always 'notification') */
                resourcetype=notification,        /* Resource type (always 'notification') */
                update_cas=Y,            /* Y|N flag to indicate whether CAS SEARCH INDEX should be updated */
                caslib=,                 /* CASLIB of target CAS Search Index */
                casmemname=);            /* name of target CAS Search Index */


  %emimacroinit();

  %if "&resource_category" eq "" %then %let resource_category=&resourcetype;;

  %tsv2sasds(file=&inputtsv, 
             resource_category=&resource_category, resourcetype=&resourcetype, type=input, 
             out=WORK.notification, dstype=table, 
             firstobs=&firstobs, lastrecread=atobs, delimiter=&delimiter);
 
 %return;
 
  %macro rename(from=,to=);
   rename &from.=&to.;
   keep &from;
  %mend rename;
 
 /* map data set vars to schema input fields */
 /* need to make this version-specific/sensitive? */

 data work.remapped;
  length deploymentid $20 batchid $10;
  set work.notification0;
 
  %rename(from=sasevent_id,to=id);
  %get_map_item(map=sasevent_headers,key=sas-deployment-id,var=deploymentid);
  %get_map_item(map=payload_properties,key=hostname);
  %get_map_item(map=payload_properties,key=consulnodename);
  keep deploymentid hostname consulnodename;
  %rename(from=Payload_Level,to=level);
  %rename(from=Payload_Source,to=source);
  %rename(from=Payload_Message,to=message);

  batchid=putn(datepart(datetime),'yymmdd6.');
  keep batchid datetime;
 run;

 %if "&update_cas" eq "Y" %then
 %do; /* update  CAS Search Index */

    %get_cas_session();

    proc casutil outcaslib=&caslib ;
     load data=work.remapped casout="_TEMP"  replace;
     run;
    quit;

    %let indexname=&casmemname;

    proc cas;		  
     %appendIndex(caslib=&caslib, 
                  indexname=&indexname, 
                  type=TABLE, 
                  load_lib=&caslib, 
                  load_table=_TEMP);
     run;
    quit;

    /* update "master" list of possible sources */
    %ck4newvals(masterlib=&caslib, mastertable=%str(&indexname)_sources, data=_TEMP);
 
    proc cas;
    /* ************************************ **
     ** COMMENTING OUT SAVEINDEX FOR NOW;   **
     ** NEED TO DECIDE IF DOING IT IS       **
     ** WORTH THE ADDITIONAL SPACE.         **

     %saveIndex(caslib=&caslib, 
                indexname=&indexname, 
                index_attr_suffix=%str(_INDEX_ATTR));
     run;
     **                                     **
     ************************************** **/
     %droptable(caslib=&caslib, table=_TEMP);
     run;

    quit;
 
 %end; /* update  CAS Search Index */
 
%mend notification_etl; 

%notification_etl(inputtsv=/opt/sas/viya/config/var/lib/evmsvrops/evdm/notification/notification/20170725Z-1.5.0.tsv,
                  firstobs=2,update_cas=N);
proc printto print='~/printto.txt' new;run;                  
proc print data=notification(obs=MAX);
	var datetime PAYLOAD_NAME payload_level payload_source;
	format datetime datetime22.;
run;
proc printto;run;

 data WORK.notification0 ;
    length SASEvent_Version $8. SASEvent_ID $36. SASEvent_Type $16. SASEvent_PayloadType $200. SASEvent_TimeStamp 
 $32. SASEvent_User $8. SASEvent_Headers $200. Payload_Version $8. Payload_TimeStamp $32. Payload_Level $20. Payload_Name $20. 
 Payload_Message $2000. Payload_Source $200. Payload_Properties $200. Payload_DetailsType $30. Payload_DetailsVersion $8. 
 Payload_Details $2000.;
    infile "/opt/sas/viya/config/var/lib/evmsvrops/evdm/notification/notification/20170725Z-1.5.0.tsv" firstobs=2 
 dsd dlm="09"x end=done MISSOVER obs=242;
 input SASEvent_Version SASEvent_ID SASEvent_Type SASEvent_PayloadType SASEvent_TimeStamp SASEvent_User 
 SASEvent_Headers Payload_Version Payload_TimeStamp Payload_Level Payload_Name Payload_Message Payload_Source Payload_Properties 
 Payload_DetailsType Payload_DetailsVersion Payload_Details;
   datetime=input(payload_timestamp,is8601dz35.);
    if _n_ le 2 then do;
      put SASEvent_Version= SASEvent_ID= SASEvent_Type= SASEvent_PayloadType= SASEvent_TimeStamp= SASEvent_User= 
 SASEvent_Headers= Payload_Version= Payload_TimeStamp= Payload_Level= Payload_Name= Payload_Message= Payload_Source= Payload_Properties= 
 Payload_DetailsType= Payload_DetailsVersion= Payload_Details=;
    	list;
    end;
   drop payload_timestamp;
   if datetime eq . then tzoneoff=.;
    else tzoneoff =tzoneoff(datetime);
    attrib shift format=best. label="Work Shift (based on local time)";
   if datetime eq . then shift=.;
   else shift = weekday(datepart(sum(datetime,tzoneoff)))+((timepart(sum(datetime,tzoneoff)))/100000) ;

  run;

