/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     output_tsv.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Write PROCESSED TSV files
  |           
  |
  | Inputs    SAS table (metrics)
  |           
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              frf  
  |           14Jul17 Made variable order of the table the same   frf
  |                   as the output TSV
  | Future:
  | End 
  +----------------------------------------------------------------+*/

%macro output_tsv(indata=, dir=, file=, version=, appendifexist=N);

 %let full_file="&dir./&file";
 %let existingTSV=%sysfunc(fileexist(&full_file));

 proc sql;
  create table varnames as
   select distinct(name)
    from dictionary.columns
     where libname eq "WORK" and
           memname eq upcase("&indata")
       order by name;
 quit;

 %let keyvars= %str('datetime', 'shift', 'tzoneoff', 'deploymentid', 'tenantid', 'machine', 'consulnodename', 'resourcetype', 'resourceid');

 data _null_;
  length tab $10 keyvar $32 header_line var_list $2000;

  tab=" '09'x";

  do keyvar=&keyvars;
  
    header_line=trim(header_line)||" "||"'"||trim(keyvar)||"'"||tab;
    var_list=trim(var_list)||" "||trim(keyvar);     
    
  end; /*keyvar-loop*/

  do i = 1 to nobs;
 
    set varnames nobs=nobs;
    if i eq nobs then  tab="";
    if upcase(name) not in (%upcase(&keyvars)) then
    do; /* add non-key vars */
       
       header_line=trim(header_line)||" "||"'"||trim(name)||"'"||tab;/* header_line: used as a HEADER row in PROCESSED TSV */
       var_list=trim(var_list)||" "||trim(name);                     /* var_list: used as part of input/put statement */
      
    end;/* add non-key vars */    
  end; /* i-loop */
 
  call symput ("VAR_LIST",var_list);
  call symput ("HEADER_LINE",header_line);
  stop;
 run;

 
 data work.&indata;
  retain &var_list;
  format shift 6.3 ; /* datetime datetime22.; */
  set work.&indata end=last;  
 	 
 %if &existingTSV and "&appendifexist" eq "Y" %then 
 %do;  /* add rows to existing table */
    file &full_file mod dlm='09'x;
 %end;/* add rows to existing table */
 %else 
 %do; /* create a new output TSV file */
    file &full_file dlm='09'x;				
    if _n_ eq 1 then put &header_line;      
 %end;/* create a new output TSV file */
	
  put &var_list;
    
 run;


	/*                                                             */
	/* Add to evdm.evdm_versions if not already there.             */
	/*                                                             */
	
		
  %check_output_tsv_version(indata=&indata,
                            resourcetype=&indata, 
                            resource_category=metric,
                            varlist=&VAR_LIST,
                            version=&version);

%mend output_tsv;
