/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     parse_file_version.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Extracts the sas-stream version from a TSV file
  |
  |
  | Inputs    TSV input file
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro parse_file_version(file=);

 %if "&file" ne "" %then
 %do; /* parse file name */
    
    %let re=%sysfunc(prxparse(/(((\d{4})(\d{2})(\d{2}))?(?:(\w+)?)-(\S+)(?:\.(tsv)))(?:\.(\w+))?/));
    %let match=%sysfunc(prxmatch(&re,&file));

    %if &match %then
    %do; /* matches file pattern */

       %let file_name= %sysfunc(prxposn(&re,1,&file));   /* filename w/o .zip */
       %let file_date= %sysfunc(prxposn(&re,2,&file));

       /* %let year=%sysfunc(prxposn(&re,3,&file));
          %let month=%sysfunc(prxposn(&re,4,&file));
          %let day=%sysfunc(prxposn(&re,5,&file)); */

       %let file_type= %sysfunc(prxposn(&re,6,&file));
	   %let vstring  = %sysfunc(prxposn(&re,7,&file));
       %let file_ext = %sysfunc(prxposn(&re,8,&file));
	   %let file_zip = %sysfunc(prxposn(&re,9,&file));

       /* will set the macro variables: version_full version_major version_minor version_release version_patch */
       /* if they exist.  Use %local/%global in calling program to access them after this macro completes.     */
       %parse_semver(vstring=&vstring);

       %if &evdebug ge 2 %then
       %do; /* dump out sub-components extracted from file name */

          %put _local_;

       %end;/* dump out sub-components extracted from file name */
 
    %end;/* matches file pattern */
    %else
    %do; /* doesn't match pattern */

       %put %str(ERROR: The specified filename [&file] does NOT match the expected file pattern.);
       %goto EXITERR;

    %end;/* doesn't match pattern */
 %end;/* parse file name */
 %else
 %do; /* nothing to parse */

    %put %str(ERROR: No filename string was passed; nothing to do);
    %goto EXITERR;

 %end;/* nothing to parse */

%return;  /* all is well */

%EXITERR:
 %let evdmerr=Y;
 %return;

%mend parse_file_version;


/*********************************************************************/
/* START        ****** TEST CASES ******  
%parse_file_version(file=20170511Z-1.3.10-SNAPSHOT.tsv);
%parse_file_version(file=20170511Z-1.3.10-SNAPSHOT.tsv.zip);
%parse_file_version(file=20170511Z-1.3.10-M.1.tsv);
%parse_file_version(file=20170511Z-1.3.10-M.1.tsv.zip);
%parse_file_version(file=20170511PROCESSED-1.3.10-M.1.tsv.zip);
%parse_file_version(file=20170511PROCESSED-1.3.10-M.1.tsv);
%parse_file_version(file=20170511PROCESSED-1.3.10-SNAPSHOT.tsv.zip);
%parse_file_version(file=20170511PROCESSED-1.3.10-RELEASE.tsv);
%parse_file_version(file=20170511PROCESSED-1.3.10-M.1.tsv.zip);
%parse_file_version(file=20170511PROCESSED-1.3.10-M.1+12DEC2017:00:01.tsv.zip);
%parse_file_version(file=20170511PROCESSED-21.3.110.tsv);
%parse_file_version(file=headers-21.3.110.tsv);
%parse_file_version(file=headers-21.3.110-SNAPSHOT.tsv);
                ****** TEST CASES ******                         END */
/*********************************************************************/


