/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     reloadIndex.sas                                      |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Reloads a CAS Search Index from previously saved     |
   |           copy of the index                                    |
   |                                                                |
   | History:  Date    action                                       |
   |           17MAR17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   
 
%macro reloadIndex(caslib=,                   /* CASLIB of target CAS Search Index */
                   indexname=,                /* name of target CAS Search Index */
                   index_attr_suffix=);       /* suffix to add to CAS Search Index name to identify associated attribute table */


  %emimacroinit();
  
  %dropTable(caslib=&caslib,table=&indexname);

  %dropTable(caslib=&caslib,table=&indexname.&index_attr_suffix);
  
  %loadTable(caslib=&caslib,table=&indexname,promote=True);
  
  %check_results(status=s, message='Reloading the index');
  
  %loadTable(caslib=&caslib,table=&indexname&index_attr_suffix,promote=False);
  
  action table.attribute status = s result=results;
  param caslib="&caslib", 
        name="&indexname", set='schema', 
        table="&indexname&index_attr_suffix";
  run; 
  
  %check_results(status=s, message='Linking the index and attribute table');
  run;
%mend reloadIndex;
