/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     safeappend.sas                                       |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Misc utility                                         |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAy17 Initial Coding                        frefor |
   |                                                                |
   |                                                                |
   +----------------------------------------------------------------+*/


/* ASSUMPTIONS:                            */
/*                                         */
/* *there will be one or more slice tables */
/* *we want to append latest slice to a chunk */
/* *periodically, we want to append the chunk to the "all data" */

%macro safeappend(baselib=,
                  baseds=,
                  chunklib=,
                  chunkds=);
 /* %global evdmerr; */
 %let evdmerr=N;


 %if %sysfunc(exist(&baselib..&baseds)) %then
 %do; /* base table already exists */

       %lockds(lib=&baselib,table=&baseds,action=LOCK);

            %if "&evdmerr" ne "N" %then
        %do; /* error flag set */

           %put "WARN: Failed to obtain lock on base table";
           %return;

        %end;/* error flag set */

 %end;/* base table already exists */


 %lockds(lib=&chunklib,table=&chunkds,action=LOCK);

 %if "&evdmerr" ne "N" %then
 %do; /* error flag already set */

    %put "WARN: Failed to obtain lock on chunk table";
    %return;

 %end;/* error flag already set */

 proc append base=&baselib..&baseds data=&chunklib..&chunkds force;
 run;

 %lockds(lib=&baselib,table=&baseds,action=CLEAR);

 %if "&evdmerr" ne "N" %then
 %do; /* error flag already set */

    %put "WARN: Failed to release lock on base table";
    %return;

 %end;/* error flag already set */

  /*                                                */
  /* Only delete from STAGING if PROC APPEND        */
  /* worked.                                        */
  /*                                                */

 %if &syserr le 4 and &syscc le 4 %then %do;
  /*                                                */
  /* Append to the TSV files in persistent.         */
  /*                                                */
 
 	%write_staging_to_tsv(resourcetype=&chunkds);
     proc datasets lib=&chunklib nolist;
       delete &chunkds;
     run;
     quit;
 %end;


%mend safeappend;
