/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     saveIndex.sas                                        |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Saves a CAS Search Index to disk (index is saved as  |
   |           a pair of non-standard CAS tables)                   |
   |                                                                |
   | History:  Date    action                                       |
   |           17MAR17 Initial Coding                        sasgzs |
   |                                                                |
   +----------------------------------------------------------------+*/
   
%macro saveIndex(caslib=,                   /* CASLIB of target CAS Search Index */
                 indexname=,                /* name of target CAS Search Index */
                 index_attr_suffix=);       /* suffix to CAS Search Index name to identify associated attribute table */

   %emimacroinit();


   %let index_attr_table = &indexname.&index_attr_suffix;
   
   action table.attribute status=s result=results;
   param caslib="&caslib" name="&indexname" 
         table="&index_attr_table"
         task='CONVERT';
   run;         
   %check_results(status=s, results=results, message='Converting attributes to table (to prepare for saved)');
   run;   
   
   %saveTable(caslib=&caslib, table=&indexname, replace=True);
   run;  
   %saveTable(caslib=&caslib, table=&index_attr_table, replace=True);
   run;   
%mend saveIndex;
