/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

 /*+----------------------------------------------------------------+
   | Name:     threshold.sas                                        |
   | Product:  SAS Environment Manager                              |
   |                                                                |
   | Purpose:  Misc utility                                         |
   |                                                                |
   | History:  Date    action                                       |
   |           10MAy17 Initial Coding                        frefor |
   |                                                                |
   |                                                                |
   +----------------------------------------------------------------+*/


%macro threshold;
 data work.thresholds;
  length resourceType $32 resourceID $ 200;
  length  metricName $50 metricValue metricMaxValue metricMinValue 8 alertName alert $15;
  resourceType = "cpu";
  resourceId = "ptnode20 CPU:0";
  metricName = "stolenCPU";
  alertName = "stolenCPU - Low";
  metricMinValue = 1;
  *stop;
 run;


data alerts;
 length datetime metricMaxValue metricMinValue 8 alertName metricName $50;

 set work.&metrictablename end=lastrec;

 array _metrics {*} _numeric_;

 if _n_ eq 1 then
 do; /* initialize hash */

   declare hash h(dataset:"WORK.THRESHOLDS");

   rc = h.defineKey('resourceType');
   rc = h.defineKey('resourceId');
   rc = h.defineKey('metricName');

   rc = h.defineData('alertName');
   rc = h.defineData('metricMinValue');
   rc = h.defineData('metricMaxValue');

   rc = h.defineDone();

 end;/* initialize hash */

 do i = 1 to dim(_metrics);

   call vname(_metrics(i),metricName);
   metricValue = _metrics(i);

   if metricName eq "DATETIME" then continue;

   rc = h.find();
   if (rc eq 0) then
   do; /* key found */

      if metricMaxValue ne . and (_metrics(i) gt metricMaxValue) then do; alert="HIGH"; output alerts; end;

          if metricMinValue ne . and (_metrics(i) lt metricMinValue) then do; alert="LOW";output alerts; end;

   end;/* key found */

 end; /* i-loop */


 keep datetime resourceType resourceId metricname metricValue metricMaxValue metricMinValue alert;

run;
%mend threshold;
