/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     tsv2zip.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  1. Zips TSV files using zip filename access method
  |
  |
  | Inputs    path and file to be zipped
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro tsv2zip(inpath=,tsvfile=,outpath=);

 filename zipout zip "&outpath/&tsvfile..zip";* member=&tsvfile;

 data _null_;
  infile "&inpath/&tsvfile";
  file zipout(&tsvfile);
  input;
  put _infile_;
 run;

 %if %sysfunc(fexist(zipout)) %then
 %do; /* zip file exists */
    %put %str(NOTE: The TSV file [&tsvfile] has be zipped to [&outpath/&tsvfile..zip(&tsvfile)]);
    
    %if &syscc=0 and &sysrc=0 %then %do;
			%put File &tsvfile in directory &inpath will be deleted.;
			
			filename fname "&inpath./&tsvfile";
			data _null_;
				rc=fdelete('fname');
			run;
			filename fname clear;
			
		%end;
   
 %end;/* zip file exists */

 filename zipout clear;
 
%mend tsv2zip;
