/***************************************************/
/* Copyright (c) 2017 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/



 /*+----------------------------------------------------------------+
  | Name:     update_rtinventory.sas
  | Product:  SAS Environment Manager
  |
  | Purpose:  Updates the inventory for each resourceType with FIRSTOBS value 
  |
  |
  | Inputs    Inventory name, LAST_REC read, last mod date
  |
  |
  | History:  Date    action
  |           05Apr17 Initial Coding                              snornb
  |           
  | Future:
  | End
  +----------------------------------------------------------------+*/
%macro update_rtinventory(action=, 
                          inventory=, 
                          tsv_file_name=, 
                          file_date=,
                          file_ext=,
                          last_rec=, 
                          last_moddate=, 
                          finalized=N);

 proc sql noprint;
 
 %if "&action" eq "ADD" %then
 %do; /* add a new record */
    insert into  &inventory 
     set tsv_file_name = "&tsv_file_name",
         last_rec=&last_rec,
         file_date=&file_date,
         file_ext="&file_ext",
         last_moddate=&last_moddate,
         finalized="&finalized";

 %end;/* add a new record */
 %else 
 %do; /* update an existing record */
    update &inventory 
     set last_rec=&last_rec,
         last_moddate=&last_moddate,
         finalized="&finalized"
          where tsv_file_name eq "&tsv_file_name";
 %end;/* update an existing record */
 quit;  
 
 proc sort data=&inventory out=&inventory nodupkey;
  by tsv_file_name;
 run;
 
 %if &sqlobs ne 1 %then %put ERROR: Update of TSV Inventory table completed with a non-zero return code;
 
%mend update_rtinventory;

